
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\xf3$\x00\x00\x00\x97\x00d\x00d\x01l\x00m\x01Z\x01\x01\x00\x02\x00e\x01e\x02e\x03d\x02\xab\x03\x00\x00\x00\x00\x00\x00\x01\x00y\x03)\x04'
        b'\xe9\x01\x00\x00\x00)\x01\xda\x0b__pyarmor__s\x83K\x00\x00PY004022\x00\x03\x0c\x00\xcb\r\r\n\x80\x00\x01\x00\x08\x00\x00\x00\x04\x00\x00\x00@\x00\x00\x00CK\x00\x002\t\x05'
        b'\x00"\xbbf\x87 \xbeW\xf7\xf0m\xb4\xb3N#\x89\xdb\x00\x00\x00\x00\x00\x00\x00\x00\x17\\\xa8+*:,\xf8o\xc0\x97\x9cx\xb71\xda\x06].\x85i\x81\xf7\xf3D\x88\xb0\xcf\xd8\x90\xd0\xb9M\x86S\n\xe0\xda\x1c'
        b"-\xabA\xfb\x80*b\xc9\xab7\xad\xaa\xc4\xc9\r\xa6\xf3\x02\xcfe\x07\xbe\xb0I\xd3[\xac\x12Fj\x1c\xf7\xcfS\xa2\xac\xab\xab\x82'@\xf7\xaa+\xec-\xc5\x06pL\xaa\xb8n\x02\xd9xQ\xca\x02\xad\xcdV\xc4\xba"
        b'o\x99[b\xf8,\xe2=\xd33\xc9\xf0~\x9bi\xa7Z\xabB0R-\xf5s\x81vU\x04\xc8\xf86\xcc\xa0\xb7\xf3n%\xe6\x16\xf9F &\x82\xb1\x08\x1c\x12\xd6T\x0c\xdc?\xbd\xfeX\x81 \xd6\x9b&Y7\x02'
        b"oXV\xae\xfc\xcf\xbd\xadi\xfd\x95AZT\x9b\x1bv\x18\x13@\x0b,\xb0n0\xea\xfbggb\xda\x8dhw\xda9{\xd3\xbc\x0f-\xcc\xf4b\xe3J\xa6\x1b\xf2\xc0\xdf \x9c{\xbe/\xf9'\xf9P\xe8\xcd#\x11"
        b"\xe9\x8cV\x96\x92\xe9P\t\xab8^\xdd\x0e\xda\x0f#\xc3.A\x9e'\xd4\xee-1\xdf\xff\xc3\xe0 \xae_+m\x05\xae\x02}\xbd\xaf:Nw\xfd(x\xd18\xa1G\xe9\xf4\xf5\xe4\x04\xd2\xf5L\xd8\xdf\xae[A\xc0"
        b'\xba\x1e\x85\x82\xee\xe3h\x12\xb0\xcb\x9dr\xcf\x83\x9e\xf6\xf6\x96\xe1\xb0s\x8eN\xb5\xef\xfaP\xf4\x1fO\xa5A$\x90\xa7N^\n|^C\xa4o(c.\xe8\x9d\xec\x83\xc5\xd0\xa2*:pi\xac\x91\x98H!\xb8\x89'
        b'\xa5\x12`\x96\x0c.\xab\xda\xba\x0e\x86O\xb4\xd8\xc7\x8ce\xac\x08\x10\xd46\xb4\xbf\xb99?u$Z\xff\xf0u\xdc\x04j\x9eXQ\xdc\xb1}\xa8\x0f\x9f]K[\xfd\xcb\xe6\x14\xc2\x93\x9e\x8a\xc4<"\x83\x80\x1a\x96g'
        b'y\xc5\xd6\xf0\xfa\x83\xd0.\xfbcAG\xbbX\xc2\xab\xd7\x13)\xe78l\xb7\\\xb0IN3\xd8\x1a\xf8\x07|H\xf3\x91A\xef\xa1\xdd\x15\xcd\xe3\x95\xad03?nK\x04\xf1,\xc9\xb3\x9e\xec\xc5\xf1p\x8b\x16\xf5y'
        b'\xbeo\xce \xdd\xe1\x8b\xd7b\xfeY9B\xe6\xccs_\xd4\xa9K#Y\x04\x07k@ch\xd5P\xd8\xb78\xf5\xb4\x1eg\x01,\x97D\xa7\xf9\xc5F)4f\xe3\x81\x08\xc7\xb2\xa81\x01G\xf0\xe0;\xd5D\x82K'
        b'\xd3\xa5I\x87\x95\x86\xa3$W\xc9\xfc\xdd\xbaY\xb1\x7f\xc1\x11tH\xf8k6R\xe1\x9a\x8be\xcf\x90\x04\x90?eDOu\xc1\x06\x88\xbeV}\xdfi\xf7\x16\x1c3P\xcf\x98!\xdc/\x80&\xfb\xbd7,\x87\xe8\xb5'
        b'\xca\x8c"^\xbb\x13\x13@\xcct\xb1\xae)O\xed\xd6g\xfa]5\xc7\xbb\xcc\x1b\xd4\xd74\x13\x88\xa0I\xc0\xd0i)lj\x9cQ\x0e\xbe\xca @W\xd2l\xf0<I\xf4,\x0b\xc3\x87w\xe9\xa4n\x05\xce+q\x0e'
        b"\xea\xfa\xa1\xdeL\xb2\xaa1'\xe0U\xf0c\xd5U\xff\xe2\xddX)\x1c1\x02\xce\xb4\xddl\x08\x02\x01\xda\xb783\x93h&\x1a\xed\x0bhS\xd4\xb9j\x97\xed-A\x12[&\xbf\x82\x03\xcf\x9aZ\xae\xbc\xb8c\x85\x1a"
        b'>\x97i\xb08e\x06\x0cK\xca\x05\x86\xcc\xe2\xf6\xae\xf3\xe6\x15N\x9clG\xd9\xb7\x8a\x0e\x9a\xcc\x05\xfc!\x9d\xac\xe9\x16Q<\x91\xdd\xf5\x8e\xbd\xac\xc5\xb6\xd8\xa8\xf6b\t\x12l\t\x1e\xaa\xb5\x82\x88!\x0f\x88\x1b4'
        b'5i\t\x872We\xb9\x91\xe6\x9ewUQ.T\xb5\xbe\x85\xf4\xf5\x14$\x8e,I\xc1\xce\xb9\xfcY\x84=?\xd0\x8a@\x0c\x94\xd9J\xa8\xdf\nT\xcd\xf3\xbf\xa9\x95\x0b\x01\x89\r\xaf\x9a\xa1+\x98k\x9d"\x14\x90'
        b'~\x1dR\xc2\xce2\xe1FF}\x10\x08%\xea\x8e\xdc\xc7T\xf8[\xc2\x99\x99%0|\xe9\x17g\xe9\xe5+0\xfd\x8e\x89\xf7Js\xd5W\xe5v\xbf\x8b\xa712\xc9\x8a\xf0\x1a\xea\x0f\xf6\x86i\r\xd05a\xbf\xfe\xad'
        b'\xa9\t\xa4g\xe6y\xf5\xf5\xfb\xab\x153\xda,\x1e\x85\xf8\xe8\xa4=\xe6\xd0\xf1\xc2\xf4\xe7\xd0\x8e\xa5cd\xd5y\x01\xcej\xec\xee\\ed\xbc\x11\xe3X\x97\xb4g/\xee\xbd\xb7\xcb\x9b+\xcf\x0cZ(\xb5~\xdb\xd5N'
        b'\x87c\xb1\xb1\x02A@\x17\xef\xb5\x91\x11\xe5pu\xe3B\xe2i\xf2\t\x85<\xd7\xca\xabp\xf1e\xe7?<\x19w=-35\xaf\xf5\x82\xeb\xe5m\xc3?b*\xd6K`av\x9c\xa4\xf8$D}\xd6b\xdd\xdd\x1f'
        b'H\x1ep~6\x97\x9d\xd0\xa5\xcch\xbe\x14\xdb\xd1\xe1\x8fh=)C\x00\xea\x16\xc7\xe2d\xefg\xdbL\x89\xa7\xaeJ\xe9\x1f\xcd\xfa\xcd\xac\xed\xbf<@\xd1\xac\xba5a\xd8\xeb t+\xc9\xd8c\xf1&\x1f\xd3\xa3\x89'
        b'\x7f\xceQ\xa7=\t}X\xc0\xcf\\\x15\xa3!\xd5\xa6\x84\xf5s;\xd9\x8f\xc3\xfbZ\xe2diN\xf2\xc5o/\x14\xc5a7\xe6?\xe1\x1dw\x0efc0\xe7\x9cd\xf0\x88,\xba\xa8\x182_\xe4\xddr\xc7K\n\x8e'
        b'M\xa9\x8bJX\xbf\xad\xe4P6\x7fH\\\xf4\xd0\xe3\xc1\x16\xa47\xf0U\xcbM~H\xfd_\xa3\xd6\xf7a<\xd7\x03\x00(c\xceY\xffm\xcb\x8fl\xa4*\x1dy\x8f\xb8\x1c\n\x8aN\x10F\x95\x1b4\xde\xc1]\x95'
        b'\xb5\xa8\t\xd3t\xca8\xf47\xd8\xd0\xceOJ\xd8\x0eoY\x90ZI3,\r=\xa0\xa6Gxj\xf5\xe0\x00u\xb1\xf9s\xc8\xbb6\xa53\xc7\xa7yI\xe4\xe8]\xedw\xbfd\xc5 \xb0\xc0\xf2\xbct,="\xaf'
        b'\x94\xc3\x9aX%\xd8`\xa3\xf9\xf5EI\x91D\x99\x15y\x93\xd9\x06\x17\xd1\xaa\xdd\x90\x9b\xf3\x8e\x1aS&_\xff"\xb0D\x0c(\xe9G&\xe7\x8f8\xb3\xe9\x05\xc3\xfc\x8ar6\x02v\x89\x95\xa3\x7f\xce_\x0b\x95\x01l'
        b'\x1e\xe5J\x8aO\xe3\x7f\xe8o\xda\x0f\x16\xe7\xa6w4\xed\xa8wr\xc2x\xf0\x15A\xec7p\xb1Xs:\xc9OK\xf6\xd3Y\x8d\xf0<\xa6LK\xfc\xe5\x93\xb2et\x9dl\xee\xec\xbf\x10\x10C\x9b=\x1c\xdb\xd0]'
        b'2`f\xbb\xab\x02\x89\n#\x8a\x07\xa5C\xa0\x00X\x87\x8dCQ!0v-\xdf\xb0\xe4\xe2H\xff\xc4\xa57\xc3c\x99nh\xac\xe8\x01\x01h\x8d\x89\x83T\xbe\xdb\xd6q\x9f\xd2V\x06Dv\xed\x8f%\xc6\xf5\xdeD'
        b'?4\x04\xf3\xb1\xa43W\x9f\xbd/\xd3o\x1eF*\x862\x84\xc9R{\xc4\xf7"`9\xd0\x0c\x9e\x94\xd2\xe4@\xd4R,\xce\xac8-\xd1\xf5\xaa[\xdd\xff?\x0f\xff\xa1\x04\xaa\xb96s\xbb9\'\xa2\xb71\xaf\x04'
        b'f8\t\xa3\xb8`D]\xf8\xaa\x88;\x14\xe7\x12\x8e\xcdv\x1ds\x9ay\x1e\x03Z\x8d\xe7\xf0\x94\x0eW\x0cQ\x93\x9b\xa4\xbaE\x1d\x1f\xf1\x85B,g\xd1\xa0D\xc7B-;\xe0\x14\x89\x11\xa1\xb1\xcb\x84_\xc64\xa8'
        b'v\xa4\x16\x92o\x15\xceuOs\xb8\x0fw\x7f9Q\xa1GAX\xa2\xc5:\x08\xf4\x1b\xb2\xc3\xe9t\x19}\xd4\xb3X9Q\x1fl\x0f\x8b\x17\x13H\xfc\xefm\x11\xcf\n\x98\xdf2\xac\x84#\xd15t\xd7VYGp'
        b"U\xb0q\xb7\x8e8+\xf6b\t\xc1\nXq\xa5%U\xed=\xe4U@\x92\xb7\xe3\xcc\x05\xec\xdd-\xd5%\x01\xa7iX}\x1f8\xc3\xc4P\x1a\xad\xc64\xff\xf61\xc621\xaf\xb5\x7fr/&\t\x95'.S\x9b"
        b'T\x14 \x13\xe9\x1d;\xecnc\xb1\x9e\x03\xf6\x01\xf0g\x98Ll\xe0x\x97\xa6\x05\xef(H\xe0$4\xcf\x9b\xcf\x90\x1bX\x86\xa9\xcc\x03\x00X\xcd\xa7\xd3r5\xa5\x1f\t\xf6\xfb=\x8b@~(\xb5\xf9#\x94\xf9\xa1'
        b',\x000w\x1a-\x07\x18\xb21\xa7@.~W\x91\xc2\xff\xda\xc0\xe5wI\xfc\xd8\xf2$\xaf?$_\xc6\xba\xf1\xe5\xb7\x9a\x13\x91\x03\xe9W:6t\x1d\x99\x9c\x95me\x83]\x88\x9ac\x7f\x81\xd9\n\xfb\xb8\xa8\xfc'
        b'\x06\x898$w1@\xa0\xd39\xe0\x1b;\xba8B\xafk\xda\x99kf\xf8"#\xb7FD\xca\x189A~\x1a\xfdP\xf2D\xe9F\xa6\xe2\x07\xdeX\xe9\xdcK\x99.\xe6\x85bt\xe2\x80\xc0C3\xd7*n\xc5\xa9'
        b'\xd8\xe62\x1e\xee\xf3\xd8\x85\xc6\t\xbd*\x17\xec\xc4\x83|\x89\xebj\xddUf\xcd\xea\xbd\x0e}\x1e\xf1\x8d\xa3\xea\xceJ\xf2\xe9;\xb6R\xa7\x18\xd2\xdf\xe7\xae\x98O\xf9\xc1\x08\x03\x05um\x01\x8fK`J\xaf\x94\x14J'
        b'\xf9\x9e\xb5O\x8cAZ\xe6e\'\x0c\x1a\xcc\xbdz\xdde\x88\'zZ\x9c\xf3\x11yK1\x05\x12\xfa6 7C\x96J\xa4 5\xf1\xcc\x02\x97Q"s:`^TMD\x12\xf0T\x00\xf4\xd9\xf2H\x1bY\xc9\xed'
        b'B\x9b\x1f\xb3\xfduA\x06\x0e\xc1m\xe7\xe5K\xac\xbd\xb3\xff\xfbS3\x01\x0c\x1e\xbfF\xbddu\x8f7@c\xba\x96\xef\xd4\xc7\x96\x0c\xc3&Po\x85\xfd\xdc\x0b\x92#\x90\x02\xc3*9\x1esJ\x8d$3\xfcz\xc9'
        b'\xff\x81\xf2\x01\xf1\xa4\xe3\xea\xf7}e\x85{\x86\xc5\xb1\xc5W\xa4-\x07\x92;\x19y\x1d\x05h\x8d\xb5\xbeR\xa7\xa5\xc2\xe1\x81\xf6\x14\xeaZ\xb1\x0cb\xc9\x9c\x13\xef]\xdb0\x00y\x06$U\xb6hm\xf2\x1b\xb1k\xe4'
        b'\xce\x1f\x8c8\x87V\x83yk\xffy#\x04i\x8a\x1aa\xa0}m\xae\x13k|R\xf2t\x82\xaejV\x05G\xb2\x10\x12\xcc\x90q\xe9o\x8a\x86,v\xe9\x8au\x19E\xb6\xee\xde\xdf;k\xcf\xe1\x9e\x14:\x94\xc3\x8d'
        b's\x8d\xbb\xbe\xc7\xde[\xe7\x96|\xb8\x11\x83\x9fQR\xf7e\xbejF\xd0\x9f\x00\x05F\xed\r\x1e\x1e(]q\x83<\x7f\x04\xe3Q%o\xdbC\x1e\x1c\xeeo\x9f\x86vS\xfe\x1b \xc2\xd0\xab\x06s\x82,G\x10\x9b'
        b'z\x12;0<\xd0a\xbf\xab\x8e\xd6\x90\xfd#KB\xa2_i\xce5\xde\xca\xf5\xd4\xc0\xe1\x1dbm2e\x19\xfetpG\xe7(\x81n\xd9M\xe7\xeeU\xb4\x02\xac\xe2hB\x87\xab\xdc=\xb5\xd7\xa7\xd5JQJ\xf7'
        b'2\xe9\xeb\x10\x8f\xb0Z\xf5\xf8A\xd4.2b\xa3\x9f\xe8\xad\x03w\x907N}\xe3\t\xaa\xa6\x87U\x04\xb2\xa6\x94\xc5\xda\x11\x80\xda\x1b\x89\xd5\xb1\xa6t\xf3n\xc6\xb3C\xa0wkg3^/z\xe0\xa2k\x9f\x00\xcb'
        b'\xe9.\xe7\x05\x8c\xd5W\xd6\x8fS\xf2[\x8b\x1f\xfb\xbd\x91\xc9%\x18\xbd\\*\xec\xd0>\xe2\xb0\xab\x99R\xdfgl\xa1D_i@\t!\xc6~\xf3$ps\xbe\xcb\xee\x08\x81\x86\x9f^\x80\x8cu\x03\xf5C\xb7\x8e\x11'
        b"V\x8cs+)<\x9b\x91\xfb7\r|\xf4\xdf\x8ei$\xc16\xe1O\x9dF\xbb\x16\x9a\xd3n\xcd5\xda\xb1\xf8\xb3\xdc\xd5.\xe9\xfc\xd5\n_\xee\x90\xabi\xbeS\xd6o\x16\xc1\xae\xf6\xa8\xa2\x8b\x19\x13d'\x94\xdc\x0c"
        b'\xe6\xc3\xb9&j\\\xe8\x91\x8d\x1e\xaaz\xb3c\xd5\xec\xa2\xcd\xe5r\xb2\xc6U\xe7\xf5\x80\x11e\x052\xbb\xd5\xc5\xdf\xbdt\xa7_\xf0\x1d\x1az\xa5\xcf\xdb\x92(}L\xcd\xd3x\x86\xfa\xe3\xc8c\x11;)d#T\x1f'
        b'\xb8\xa9\xe2\xdcXR[\xdc\x08\x8aL\xe7)PB\xc0*\xc6\x05\xbdx\x90D\x91\xeb\xb0\r\xd9!\xad\\Mi\xb0u~\xb3\xd0\xb6\xf9K\x1e>&\xe6\xdc\xfa\x17[%\x94z7&\xb2\xd6\x13\xe6\t\x17\x19\xec\xf8\x0b'
        b'\x0b>\xe5\xf5_\x80\x19i\xff\x99\xf5\xac\x8cJ\xe7\xc9\xa38\x8co6\x86L\xa0\xb1\xf9\xa3\xe2\x03\xad\xc9v\xfc\xcb\x18\x8e\x0e\x95CpMG\x8b\x18\x81\xacv\x03$\xe9O\xf4(\\\x14d\xb5\xcb\xf4\xf5\xf5\xc38\xbe'
        b"Wj\xf8O\x1d?\xa5\x9a$`5\x84s\xf1~\xd7\xcd\x03>{E\x85\xb6\x9c\xc4eR\x13\x17,\xb6\xa7Pa\x0f\xebf\xde\x86\xad\xba7\x9d\xa3\x8dy'\xfc[\xd3\x11\x15d\xa6\xb4-\xb1\xef\x08\xbd\x91\xbf\x00\xbc"
        b'\xcdKf\xd8\x8e)\xeeX\x06-\t\x8a\x0e}!\x03oR\x88\xbc\x85\xcc\xaf\xb7\x9f\x95{\x8bH\x03\x17v\xf7\x91\x85\xb7\x95!"\x94\xe65\x01D\xaa\xbc\x06bO\x9f\t\x84\xfe\x1c.\xfcH\x9e\x97Z\xa3\x19H\xfe'
        b"\xf2E7'\xb6\x1b\x88\x8cj\xbd|\xb0c(\x14\xde\x8d4\xa0\xca\x86-\x1a\x99\x896\xa4\xefX\xf5$\xd1!\x8a\x7fu\xf2\xc5\x07\xbb\xdcL@J\x9e\xad\xeb%w\xf8=\xdc\xf7\x90a\xd2\xbd\x07\xff\xd1z\xb7X\x86"
        b'Z\xd4\xa4\xc5z\xf5G`\xa3\xa7~\x08\xe6E\x97\xfd+F5\x95\xd4\xf9\xf2\xe2\xafF\rt[\xda\xef\xf8\xbf\x03\xbdO\x9e\x85\x80\xb6bCB\x04\x0e\x99\x96\xa3:2\x8d\x8f\x07\x87z\xb7\xd8\xf7] [h\xa5@'
        b'i\x0e\x9b|\x80\x80\x9a\xe5\xab\xe4(\xe28\x03\xa8s]\xcd\\x\x00\xa6\xe5\xdf\xe8\x99\x03\xc4U\xdf0B\r\x94p\xb6\x98^(\xa0\x8cl\xe2\xe4\xb8B\x00\xab\xf3v:L\xf308\x08,(m\x9b\x98\t5Y'
        b"\x8e\xfa0N-\x9e&\xb0\x02\x1c\x1cz\xe0$s\xfc\xb9)\x8f\xfa\xef\x11\xdb\x9b\x8f\xd2\x04.g\xb4A;\xb6\xaf(\xc1\n\xd3\x97\x92\x16\xca\xbb\xb3\xb4\xee\xef\xf3i\xdf\x16G\x8a\xe2\xd2\xc9\x0b\x98?'\n\xab\xe5\x88"
        b'\x02\x95B\x86\x01\xcf\xd9\x84\xf5\xf3V\xcb\xd4\x86\x1a\xcek(\xf0u\xf6"\x1a4d\x99\x01i5\x04C\xd9cS\x1c\x06\xa1\x84\x0c\xbe\xb9\xfe2\xddU\xdb1G\xd6K\x94\xf7rx\xa9F\x1d\xef\xc7ay\xe3\x89\xa8'
        b'\xce*\xc6\x7fbK\xbf\xfd\xac\xd0\xdem\x1c\xc2\x8d\xecA\xed{u\x1d\xd517q\x16\x92\x03\xe4T\xa6\xda\xc2X\xfa3\xde\x97\xd8O\x9b\xee(8\xff\xcd\x06\x94!\xfa\x9a\x92\xab"\\\x99C\xfb:.h;G\xfc'
        b"\xf5'\xfe\x00\xd5\x05\x12F6-\xf9\xd6p\x01@#\xccBZB8\x8f\x1c\x96\xf8\x8eX2\xf80\xdfC\x129\x04\xbc\x98\x88\nsC\xc9B\t\xc2\xbc\xdbt\x9c\xa4\r\xe6Z\x1d]\x05\x16\x14\xc0\x89\xc1|\xe9\xed"
        b'\xbb\x85\xaehl\xdf\x8e\xec\x1f\xfe\xe6\x86\xa9d\xd1\xd3[c\xb9\xaf\xc8B\xc8Q4r2\x8d\xf9"\x1e\x90mMo/\xe8\xe2\xb3K\xa34\x92\xb3\xc2`\xc6\xcdY$\xda+\xa6\x8b\x95`\xab\x06\x90o\x08\x9a\x1f\xac'
        b'\r\x8a\x0f\x0c\x93x\xe9\xba:q\xd1\xed\x80l`\xad\xd0\x11N\x9c\xdf\x01<\x8d\xc6#\x91\xe3,3\x0c\xc7/\tAt7\xacO?JwHQ\xe2V\x9f\xa5\xdcZ\x99\x19\xdb\xcb\x07\x07\xf9\xbc\xcd;.\xff\x1b\xf0'
        b'\x9c\xf5\x84+\xc5f\xec\xdau\xa1\x96\x1d\x16dI\xa3\x8f\xe9L\xb6D\'E\xfbUf\xaci\xbc\\\x102\xb2iD\xe3\xd3mih\xfe\x8ec\x81\xd8\xf6\xe4\\&\'\x01\xcb8\x12E"\x95G\r\xd4\x15\x93\x00Y'
        b'\x8a\x8b\\\xad\x8a\xa2\x949@\xb4\xe6?\xf8\xfb\xd9}t\xe5O\xe1\xd4\xf3\xc5i\x9bf\xd3\xc2\xe4\x06R\xd5\x06dX4\xe3\x08\x9ck\xb7\x9aNy\x91\x14\xcc\x93\xc1\x8cQ\x1d\x0f-\xbf%^\xf5\x80}\xa9~\xb9\xb7'
        b'?\xc2e\x88\x8e\xcd}\x18\'\x86\x99\t\xc1KI\x9ep\xdf\x9e\xef\xf3\x90#N\xff\xfa\x84@\xf4\xdb"\xf3\x93+nP\x92\x96\x12Z\xf1\x0eb\xa1\x8f\x1d\xc4\xde\x16\xf6D\x98\xd5~l&\x96\x04x!^`3\xbd'
        b'\\C\xa3\xae@?\x90\xf5.\xfb\xb6\xc9\xf7>\xb9\xdb/t:\xa1\\Xe\xb4\x99\xef\xe2\x99:\x84\x8e%9X\xae\x17=\xfc\x1e\x13 MH\xdb;\xc2\xa1\xbb\x80\xbc\xca\xce\x9b\xca\xa2\xe1\xf6\xbf\nyE\x12\\\xd2'
        b'$\x01\xe8q\xd8\xdd\xb8\xed\x94\xad 0\xabp\xe5\x17={\xd8a\xda\xb7\x7f\xe1]\xbc\xcd<\xcd\x06\xbfg\xe90\x00\xf0\xcc\x0f9\xb1\x90.\xc3;\x1bEa\xb1\x82\x93?\x8fB\x9e\x0b\xbb\x06\xe61fy\xb8\xd5\xb8'
        b"\x15\x14\xa7s*\xd9\xff\x9d\xba0U\xd9}\xa4\xec\xd8\xc6\xc3,\x07\x9a\xb5\x16\x12\xbf7B\x8f\x121\x1b~\x17a:![\xee\xc7\x97K.\xe4\xc8\xd1\xdd<\x9ah\xf6\xa3\xb6Y\x19'\x1eb\xa2\x87\xdc\x810\xb5\xf1"
        b'x\xcc\x16\xe1\x1a0u,Y\xbb?\xb0O\xa6,\x146t`\x83)\xb7\t[\xadd\x8b\xcd\xb4gx>u^6\x06\n\xf5r\xe6O\x84\x7f\xe7s$4\xcd"d\x87p\xd6-\xbcL\xef\x87\x94\x94\xac"\x10\x1a'
        b'~|g\x94\x96Oh\xd9c\xacQx2\x1c\xf1UmQ\xa6*\xb9\xcd"h\xa81\xc5A\xe1m\x89\xe4\xd3f^\xa6\t\xf0\xb6\xb1T\xa2\xe3\xae\x1a\xce\x80c[\x01t\xfa\x9f\x01\xf96,[wN\x10\xa4r\xd2'
        b'W\xfd\xf7}Q\x99\xa7\xe2\x89\xcc\x7f\x98O\xa4\x11s\x9f\x91k5\xc0?4\x81d\x01\xb3\xcd\xac\x00\x07^]\xe4_~\xbc\r*\xde\xa6\xb45\x18\x05\xfb\xbc\x08\x8b\x7f\x06\x19\x9c`y\x1e\xc3\x9a\xfaK5O\x93\xe8'
        b'qz\xe1\x1b}\xba(\'\xa7\x8b\xe8\xdckL\x8c6\xf5\x97\xf05\x17l\xef/&\xe9\xc38\x8f\xaa\x93\xddd\r^R*\xcb"xo{\x9f\xf8&\x9dO$^;L\xeb0\x1d\xc0A\x85\x86, ,\'MA'
        b'd\x89\xdfp\x1f}\xd6\x9d\x92\xae\xb8\x17\x97\x92\x9a\x99\xa3\xe9\r\xe3\xc5\xf3p\xc2d\xf4\x1a\x1f\x165<\xe5\x1e\x03\x14Tc\x84\x7f\xdd\x02\xb0\xe1\xa3\xc5q4\xf2\x142\xf5\x16\xe1\x98\xfa{}\x10\xe3ns\xa0\xceZ'
        b'<OQ\x0e,\xb7Z\xe1\x1a Ya\xf9\x1a:\xae\x10\x84\xf1\x94\xb2\xb0\xc32\xba{\x9avw\xf9b+\x90I\xb5\xc0\x83\xf5\xa2\x8be\xb8\xf1\x88\xb9\xa6=\x04\xd1C\x1f\xb1\xd32x"\x18\x0e\xae<\x86\xc1\xb1\xf9'
        b"[\x1d)\xa7\xf4\x07\x85\x00\x99\x12?;\x93\x8a\x18\\-\xb5'\x05\xf7M/\xbazI\x0e,\x0e]\xe56\xbf\x04X\x19\xc0\xac\xe5w\x0f5\xb5^\x94\xfe*\\\x9cq\x7f\x1bR*f\xbb#L\x8e5F\x16\x9e\x89"
        b"\x14P\x18\xd7\xf4\x04u\x97\x97E=\x9f\xa4\xd2Z\xa9\x93\xb3}\xdb\xfd\xe9\x9a\xfc:\xa24\x8cZR\xfa\xd9\xe0\x13\x83\xa1\x98\xac_\xac\x9d\x95\x87I\n\xbah\x81\xee\xed\x19\xa7\xff/Q|\xdd\xc3%\xb0'\xa5\xca\x85"
        b'6"\xc7J)\xa2\x96\xa3\x13;\x83Gc\xc8\xdc\xc6\xb3\x7f\xfatnk\x01O\xd8\x19\x0c\x82\x11h\x90\xac\xca\x15\xae\xa86\xc5\x15\x93\xfdU\x0e{~\xb1\x10Xs\xf5}y\xfd\x9a\xe0s\x89\xe0\xfc\xb5\xd4\x01\xe2\xda'
        b'M\x87R\xcbf\xcc0\x91d\xd4\x1a:j\xbaZ\x88iy\x1c\xff/fd\x07\x8b\xe15\xca\xbd\n\xd8\x96\x10P\xc0\xc5\xbau\xf3h\xe4\x94w\xa1\xd9\x18x\xa2\\\xbd@+\xed\x12\x17\x93\xd2\xd9O\x03\xbb\xb1\xc4<'
        b"\xd1\xd2\xf4\xde\x90X\xf4\xb3\x88\xf6\xf5\x10\xa2`\x84\xf3\x8an4\xf5;5\xa9\xb4\xa5\x87n\xda\xf0\xd0^ff\xa3'\x07\xc4\xc9\x18dP\xa0}\x98\xb4s\xc6\xc4M1w\xdd\xa1\xcd\xb3u\t-\xa8\xf7\xe2\x1c\xd9a"
        b'\x92\x1c\xe8\xfa8\x7f\xf9\xe6\xac\xc2S\xc6S\xf8\xe9\x06\xa21\xf8\xd2\xfa\xfc\x8btY\xc0\xecD7\x18x\x98:q}\xa8\xb0V-z\x8b7\x1d\xf5\xdd\xc9\x91\xc3T\\\xfb\x89\x81\xaf\x10\x8f\x80\x1aw\x85\xa5\xe1\xb0l'
        b'\xb8@\xf2WH\x0cf\x1f\xec\x83\x8a\xa2\x03\xc1g\x17H*\x8b^\x9eXt\xd1\xd3I y\x90\xde\x9c\xe5\x9f\xcb%\x07\x0e\xa3XI\xd9\xda\x9d\x9c\r\xbd\xa0\xc4I\xa1$\xe1\xec\x9f\xab\xbb\xec\xed\xec\xc6`\xe5\xa4M'
        b'\xad\xa2i\x9d5\xe3\xaa#\xd1\x9e\xa3\x1cj\x0c\x992\xf34B\xde\x04\xcb_^\xdf\xca%P\x15\xa1-\xfe\x1c7\xe4\x8c`\xfc\xbc\xec\xe4\x9f\xf2$\x90\x87\x02f\x96\x84e\x0fcd=\xd4Y\xcd2\x17*\x0e\xb0\xd0'
        b'\xa8\xce\x7f\xb1\xc2$m{g\x9dou\x11\x15\xe6N\xc4\xc6<\xb0{\x02\xbd\xc7\x0b\x98]_u\x9b\x19#\xcc\xab\xae\x1fqe^\x87\xcf\x83cx\nbpw"\x87\xddk\xe9(j^\r\xe76\x95\x88LD{'
        b'\xd1NRt\xb5\xfd\xf4\xf8\xfeA\xda\x98\x91e\x8b\x93\x91\\\xc0w\xcf\xf3w\xcd\xf3\x89\x8f-\x87\xd6o5TH\xbcWI\xb2\xf9&\xbe\xde\x02\x9f\xfa#\xd8)\xcf\xb9\x03\xf8I\xd8{\xce\t.o\xfa,\xbe\xb8\x03'
        b'\xde\xdf\x19\x9dyof\xd7|\x93\xc2\xdaA\x83\xc3\xf4<\xaf$\xdb%\xb6#\xed\x89\x94\x14\xb11\xd0\xdc\xf2\xe1\xefFz\x16sz\x81f\x1d\xa7{\x8bg\\a\xe6x\xb0\t_\xcb\xe2\x1d\xf9\x9bH\x04\xe9\xbf\xea\x0f'
        b'\x87@\x10\x7f\x0e\x12\x96G\xc0\xf5\x05\xbc\x83\xd5\x06\xf9N\xbb\x85%VU\x9b\\\xbc\xd6\x92uF\xd3\xa0\xb1\xa3\x10(\xc6v\xbaZ)2\x9d\x93\xc3p\xa2\xdd\xf2po\x92\xa2\xd99\xf7~\x14\x90{c\x9a\x8dh\xf8'
        b'V\xae\xb1\x0f<x\xed\xfc\x0b\xd0O\x96T\x98\xccq\xf3\xc4\r\x99\xe4|\xed_\xdb\xa8\x0b\x1d[#2\xa6\xb88\xfeq\xb3&\xf47E\xedd\xda\xf24\xbf\x0e\xa5\xe4N\xc6\xb8D\x9cAq\xed\xa0x!\x81X\xe4'
        b'\xdc\ts\x12\t\xa8\x7fw\xa1\x864W\x07T\xd0X\x7f8(a\x12}#\xc9\xba1\xe1\xc9\xe4\x008-q\xd1\xca\x91\xe8\xb12\xe6\x1e\xb0\xdd.\xfdU\xb7\x96>\xf1"\xdfm\xb4#*\xab\x10\xaaVc\x85yk'
        b"\xab\xee\xbc+\xe0x\x93i\x08\x9dVnVE\x02M\xbd\xbe\xfa\xfa8\x8f\x1b\xbf\x86\x8b\xedVI\x8a\xd0T}&\xa6\x9f\xf4\x9c\xc3,\xbeY\x8d\xd4T\x9c\xeaf\xf7'\xbe\x99\xc6~H\xff\xaa\xe1J\x8b\x04\x9a8k"
        b'\x10t\xa7^\x94\x17F\x1b\x1f\xf8&WH\xa2\xf3\xec\x85A\xe8`!\xac\xf9s\x1c\x9bw\xbe\xd5\xfd\xbd\x94\x86\x81Zr<\x08\xf1\xde"\xbfp\xa7\xb2\x81w\xe3b\x8fCE\xab+\xdbr i\xe4f2\xad6\xd7'
        b'\r{M\x8a7\xe3\xb4\xe4\xe7\x18\xab\xb5y\x9f\xeb\x94T\xdd\rN\x1bR\xc6\xaf\x9du\x81h\xa4\x99\xd9\x91\x86~N\x90\xa1GXA\xae\xa4<\xba\x10P\x1a,-\x97\\\xd6\x1c\xe9x\xe9Wf\x95\xf2[\x96\x99\x91'
        b'xLcgf\x06\x91\xef\xbbj&\xa7\x89\x85zT\x96\x05L\xcc\x99\x84\x03js\xc7:\xa9\xc9\xe7\x08H9\x1e\xb6\x14\x1e\xe253@j\xeeZ\xe1\xbd\x9fv%G\xcc\x85\x95m7I\x1c\x11h\x9d\xe0\x02EN'
        b'q\x1b\x0fw\xa9\xa4"/\xfb#\xc5\xc3\\a\xfdi\xf6\x80\xdd\xd9\xdf\r@s>\xbeB.\xbc\x85\x06_tG\'\xec\xed\xb8\x06\xd4])\x01\xf5\xe4\xf3+|o\x1fWF5=^\xbe\x8c\xbek\xa38\xe4]\xd6'
        b'x\xf2C\xb6\xe6\xf4\xa6\xb9\xbf\xb8&"6:bqJ0\xbd\x07#\x1c}6\xf9\x86|\x83_z\xf3C\xbe\xe8\xa1\xf1\x1d\xe2\x88Xh\x19$\rX\xcb\xcd\x08\xf6\xf9\xbc\x00\x9a^sf0/xbQ\xbe\x11\xf3'
        b'U"7\xd5S\x9bdt\xa4Q\xc0\xb0\xc2PT\xdd5r\x02`\xb3\x07p<;\xf1H!\xe8\x19\x14\x95\xb1 B\xfa\xf3I1\xdekP\'V\xeb\x87\x82\n\xda\x863\xfbHR\xe2\x12\xc6\xc8x\xe2F\xbd\\\t'
        b's:Q%%\x00\xc43<\xed\xa3Y\xee-\x9d\xcfo\x807\x91\xbc\x0e\xd9z\xa1\x88\x99\xc7\xc3w\xb2\x01\xe4\t9 \x1b\x81t\x1ao\x18]\xe3\xf6G5t\x92\xe2\xcc\xe5p\x9c\xc6\x18\x07\xf8\xaa\xa7\xdc\xb0TZ'
        b'\x99\xa7\xbf\x03OX*Zj{\xa8\x00\xaa\xf5\xf5\x11"qK\xfd\xfa\xed8%\x8b\xf0\xaf\xb3\xb8\xd7\x16\xc7{\xa2\xc6\xe0G\xf3\xa7\x14\xd9\x10 x*\xbar\xe3\xdc\xcc\x9f\x9baui\xe0\xf6\xfaa*\xd6\xb1\r\xa1'
        b'e\xca\xd9\xdaY7\xfa<\xdb"u\xba\xb2l\xbe^Si`\xc5\xd9tE\xcb\xe3QMn\xbe\x83"\xb8\x03UL(d\x1b\xf0\x84N\x1d(\x9e;\x7f\xae\\\x82\xab\xa4\xa7b\xda\xec\x03\xd6\xc5N\xe2\xd6a(['
        b"\x88\xefo\xeb\x96\x01$|xD\x10\xb4\x95\x94\x1fn\xc6\x9c\xfb\x8f\xd0y\x8f\xb5\xa3k\xd0\xbd)\xd2@\x18\x8a\xd7{\xb0\xbb,N\xb0X'd\x87r\xd6\x93\x1d\x97\x8c\x90\x9239\x1a\x90\xd8sH\xfb\\\xe2\xc9\x7f"
        b'\x01e\xa5\xda\x8e\x14\x91\xd6\xf2\x89\\\xed_*o\x0b\xd2\xe8\xa9\x1fs\xe6\x83z\xb4<\xb0!W4 \xd5s1~d\xf29T\x024-{o\xe4Y\x82\xf3,\xa1a\xd9+\x95\xcd\xcd$\xf2\xbd\t\x02\xd5;\x1f'
        b'\xbe)H\x1c5\x08\xb7\xfa\xd1\x03\x02\xd4\x8e\xb4N\xb2N\x8e`\xed\x95\xdac\xcd\x88\x16\xd7A-\x94\xef\xa4\x0b\x83\xea\x1cY\xa27P\xd0mCVe\x86\x9a\xf4\x82\x19\xe9p\xacpR\x96\x99\xa4VG\x1b\x97\xea\xe8'
        b"}\x834\xaf\xbd\x85\xca\x9d\x17\xc5B4\xba\x94\xdc&]\xc9^J\x1c\x11\x97D-\xdcE\x82\xf5q\x10\xa8\xd6\xca\x8bUd:?\xe7g\xaa\xdb\xdc\x15M>\x0c\xcf}>'\xfb6\x96\xa2\xc6x\xce\\\xd4x1\xf1"
        b'p\xe9\xb0\x8b\xe6\x97\xe46\xd0\xe3\x88\xd5\x94\x87\xd3\xc4\x10<j\xbc_\x94\xc0D\xf0\x1d\xe6\x85\x15\x13\xf6\xd9D\xa0\xecE\x88\xe0\xfd%\xecP\xd8#|*Z\x1byW\xc2\xf4\xa6;7O\\\xbb@\xb30A\x17\xcc'
        b'\xcb\xed\xcb\xb4lL\x85\xdb_\x96\xe1\xa9\x87\x03\x7fq\xe2@\xd3\xb5\xb35\xae-\x93zu3\xd9\xe8Ls{\xe9\xd0]\xc6\x17-\x07L\x19\x99E\xb4Y\xf0\x8f\xa5\x15/\x04\xa0\xdbZ(}*\x9d#p\xbb;C'
        b"\xbf\xd2^\xb4\xd4\xc1\x18\xf1\x07'\x97\xcc\x92\xebE\xd0\xd3\x0b\x81\xaf<\xfb\x9e\x89*\x1f\xb3*\xd9W?c6?zV\xe0\xaf\xa0\xd9\xd79T*\x1d\r&\xe0\x16\xea\x80\x8co\xd1\xfb\xf5E\xc9N\x1d\x14$\xc5\xe1"
        b'\xdf(\xb4\x19s\xb33@C\x0f\x02<fR\xc6\xfd\x05\xe3\x96*\x1f\x8co\x11\xea\x96\x85\x96\x03\xec\x1e\xe0\xd4\xefa\xa8\x0fH\xa4\x99\xb2\xfa\xb8\x1c\xf1\x88\xb4*\xaf)\x82\xaa\xfcx\xc1\xee\xd0\xfe\x15\xb9\xbeJiW'
        b'\xee\x9a\xab\xba\r(T\xca\x1a\xe5F\x9ab\x85%\xff\xc8\x16X\xa3m}+\x83u\xbd\x9cL.h\x99\xbb!\x92\x08:\xd6\x87\x98\xbei4\xeb\xbe\xdfEd\xd5~:\xc2d\xbc\xf1\x87\xee\xaf\xde\x9fZ\xffg\xb7\xe3'
        b'*\xd4tz\xb2\xce\xd9O\x00u\xe0\xe0JB\xf3O;T\x9b\x88\xfeY~\xcb\xc5Dq\x04\x06\x13\xa6\xa0\xb9\xd8ub\x80\xd9v\xb0\xebZ\x85\xe4\xbadfT\xde\xbc\xfa3\x08\x92\xe3\xae\x7f_\x17]\x82:\xde_'
        b'\xb9\xfb\xa8px_\xcd\xfa\xab\x8b\xdb#C\xf4\xa6\x12\xba\xb6K\xa1\t\x93\x13a\xec\xb2>\x99\xf2\x87\xd8\xd2-M\xaa\x97\xb2\xde\xe6V\xdc\xc1*\n_\xa3P]}N\xbe\x9c\xa0\xdf+\xd9{\xf2\x08\xfb\x99\xa0\xa6\x95'
        b'\xb1a?\xf3\xcc\xae\xe4\xd4\x9d\xac\x9fb_\xa0\xb3Oi\xee\xff\xb3\x80\x9e\xa9\x15V\x01\xcaI\x87\xfd\x8a[D\xc9\x11h\xf7\xf0\x8e\xc2O\xabM\x05\xd5\xa3\x14\x9dR\xe5\x03\xb4\x03\r{\xec\x1a\xe4R\xc7\xa6.d\xf1'
        b'\t\x06\x90\x9c;\xb4\xc9\xe7[$H?\x82\x9bG\x0fw\xf2\x17\xfc\x1c\x12\xc5\xde=\x8d/f\x07F9\x98\xde\x1e\xea\xe6ls\xc4\xb9\xd5Xx2v\xc6\x00Q\xc8#\xf2~\xc5]\x8f\xef\xbe\xb5=\xbe\x1c\x0c&C'
        b'(\xed8\xef\x91\x990wqV\xc1\xd0\x98\xfb&\xafO\x8d$\x16\xe8[\x1f\xd6{\x1f\xcc.\x0fp\\# \x06oN\xb2\x81\xcdo.\xe6\xcf\x17\xe3M\x83\xb0\xe3\x9a~F\xdc,7:=s\xaa\x1f\xb2\x1d\x8f\xa7'
        b'\xf0J\xe67A\xb1;4l\xbd\xa8o\x18\xd9W\x01\x05e\x07/.x\xd5\xca\x81=\xa0\xe9A&\xd3X\xe0\xf9\x08\x19\xd3\x00\x11WE\x1aH|\x19O\x0e\x15\x06\xb0\xa2\x8b\xe7\x01\x7f\x1b*]Rx\xcf\xb8H\xd0'
        b'"\xd0:0\x08U"<\xae\xbf\xd5G\r(-\xb7g,\xbeZZG\xb9W\x10 \x96\xa4\x9da\xff\xbf\xab\xe1\xfc\xc6)\xd2\x99\x8a)\x1b\xc7\xc8u<\xca\xf8k\x8a\xfb\x18\xe7gzjV\x9f\nqf\xa4\xb9\x02'
        b'\xdf\x1e@\xbd\xcf\x93}\xc3r\x97\x03\xea\xaeL+\x0b{\xffI\x16Z\xeb#*\xf4\x9el\xf3\xe9\xe0G\xe0\x0c\xcb$\xe8\xc9\n{)"\x9f\xcd?"\x7f\x17\x16\xe7\x19Ye\x07Xd\xacAM\x15P\xfe\xcd3\xb2'
        b"\xa0NO\xb0b\xbe\xa2My\xb0\xa31\x13y\xc8=\xa5\xc9\x13P\x82\x9du\xdb\x86\xa3#\xa6\tvZnw{\xa9\xe3\xb7\xa7\xd8Z\xebr\xd2\xe1>4p\x99(\x92\x01\x9cq\xab\r\xd8\x8b`\x0c\xd2rq'\x13"
        b'\xa9\x94p\xf2O<\x04\x88h\xa5\x01:\x88\xd3\xc5\xdf\xb1\x96\xc1m\xec\x8a0\x00_\xcd\x87v\xfb%z&2\xab\xbeX\xc4\xd8\xbf\x04N\x12\xd6\xd7)\xf6\xdf\xd4%1y\xda\xa7\xf8\x97\x88\xdd\xcal0/a=\x16'
        b"y\x9d\x1bQ\xbe\x97\xe6\xbd\xabU\x0bzcT\xa9O\x94\x90'\xb4\xa2\xac\x8c\xe4\xee\xbe\xeai1\xf3\xded\xef\xb2W\xa5\x94\xfc\xbdTe\x04SV\xc7\xa3\xfe\xce\xc8\x9a\xe0\xd1T\xb6l\x7f\xd9\xd7\xb2\xc2]C\xd9\x00"
        b"3T\xe4\xa2$\xe2F9scxD-\x93\\y\xfe8\xb3\x94\x8a?o=k\xe3oi\xae16g\x85\xbb\x19\x99\xfa\x83\xdd\x0f\x81,\x90\xbb\xe2\x1f5L'K\xd2\xe0/\xbd\xe5\xdb\xb4\xf7\x07\xab\xa0E/\xaf"
        b'\xe3G\x02g\x061!\x07\x08\xb3y\xb3\x86\xdeqa\xe9\x1b0\xed\x13\xe6\xb3\x17\xe7\x0fMf\xa7f\x02\x0c\x85\xef\x15u\x93\xd3B\x1f\\\x90d^\x83} \xc9\x00\xb5\n}\x8aj\xb8)\xb9\x0c\xe1B\x1b\xc8@\xcb'
        b'\x08e\x8a:yQ\x95\x84G7\x1d\x97\x8c\x9a\xc6\x91\xb4\xb7p\x00\xb2Z\x8cz\x8b9\xcf\xdd\x18\xa9p\x15V\xdf\xf9\xfe$\xcc\xf1\xde*\x8a\xe3\xc7\x14\xe2Sv\xe4\xbb\x9el\x115f\xba_\x1b\x07Q\xff66\xdb'
        b'\xf7?3\xe9C\x95w\x99\xf5\x08p\xfa /\xdbO52M\xefj\xe8\xd66(\x18+\xc5_\x95\xef}\xceU\x89\x9d\x0f\x14\xfb#Z\xb3\x90\xf2d\xfbR\xdey\xcfi\xd5kI1\x8d\xce\xf6\x11(\xae\xbb\x88A'
        b'\xcc\x02\x87\xb7\x8d\xd7\xfd\x0c\xf9\xae\xbc}\xa4\xa5\x1a\r\xe5\xf6\xb3e\xcf\xda\xc4\xd0g\xfc\xd2js\x1d@o}\xc0\xbfW>\xe2\rQBw|\xe9\x9c\xa2\xb3t\x0c\x0e\xe6\xc5_\xb0{\xba7\xd7\xf3\x12\xd4b\x90\xa6'
        b'\xed\x07=`\xc8\xca\x9an5\xf1U\x08v\x9b\xa1X$.m$\xab73\xaa\x89\xac\xf9\x11\xa8\xdb\xb8\xb6_\xda\x98\x08\xa0s[\x15\xbe\xc5\xb6\x83\xa7f\x97\x0c\xb1\xff0\xd0\xbfUc\xe0\xcc>\x9fc\xb4\xd7\xe38'
        b'\xcf\x17S\x13hp\xd6\x14\xba\xafa?\xd61\xe8\xfc\xc9\x139+\xfb\xae\xb9\xec\xdf\xe9d\xdal|\x8d\x97o\xed>i3\xcfA;\xa2\x87\xdb`\xd1~h\xbf\xae\xaa\xeb\x0f|\xda\xd9\x052\xcd\x80\n\x86u\x1d\xf3'
        b'\xdbY\xdd4<O\xd5\x13\\O6\xea;2\xe7\xf1\xde\xb9\x9aV\xb3{\xca\xd4\x82\xbb\xa9\xd6\x8e/|\x1c\x97\xf4ww\xe9a9Z\x85\x97\xfdN\x16\xeb\x80\xa6\x86\xe4a_Pn\xb2\xe5\x8b9\x19sOV\xbd\xff'
        b'\xa1\xf7c8N%B\xae<\xa8#B\xe7\xe5v\x03\xa0\xd1f\x98\xe7\xad\xfd\xda\x17\xedn\x19U\x9c,\x8c\xc0\x1c\x80\xfb4\xdb\r@\xee(1\x85\xcf\\F\xd5\xa1VL\xb4z\xeex\xd9\xfb\xc0\x12V\x18*\x8b\xc5'
        b'\xf5\x83\xa7^\x08\x05k\x1b\xb9\xa1\x9e\xde\xc8)\xf0<\xaf\xd8\x9c\x90H\x1d\\D!%X\x07\x06\x13\xe8\x1a\xf6\xae\xa6\x82\x8b\x88z\xeb\xf1\xd5\xb6\x0e\xea%5\x19\x92\xc9%Y\xa9\xfa&\xa5\x03\xf9\xe0\x88\x06\xc8!G'
        b'\x9b\x12\x0eI!\xeb{\xe3\x02\xe1\xf5=\xab\xb3\xaf\x14\xb8(\xb9\xeeM\xdc^\xd4\x08>z\x8c\x0c}\xca\xb1\xb20\xc7\xdf3\xa5y\x99\xd7\xf8\x9fq\xbb\xc5\\\xeb3\xda\x81\xbfD\x926YN\xf3\xc1\x85\xbfWj\xe0'
        b'(\x0b|N\x04\x86\xe2c\x1b.\xa9:\x91\xb7\x84\xd7\xe4\xc3Q\x16\xf5\xb3\x82p\xae\x9d\xe2\xa4\xc8\x8c@d\xf7\x1b\xa8\x81\xb0+A\x12n\xc0=\xbd\x05\xadF\x10\xaa\x9f\x05\xa8\xfcq scv\xbb\x04F+\xa7#'
        b':7MN\xfdt\xdb\x90\x8a\x8d\xe7Z\xa5\x9av\xf7SY\xbd\x16\x84}\xb6\x06I\t\xec\xde\x11\xf9pst\xf8\xfc\xd0}\x90\xd8-\xec\x19\xf8\xf0\xe6\x97=\x13\xb4\xe4\xb5\xbf\xc0TA \xdd\xdcU\xb4\xd8M\xe5#'
        b'\x06\x91\xb9%5\x9e\xe9@\x92J\x9cE\xaaC\xc1O4\xa1\xb8\x1cO\xc5\xc6\xe2\x06\x12\x05\x86\x15\xc7U\x96<\xeb)\x0cP\x86\xec\x0e\xdb0\x02\x1f\xe0]\x80\xbe\xd0\xc1o@\x8ey\xf1\xd1\xa2\xdc\x114\xd3\xa0\xa1\xaf'
        b'S^\xa8\xa5\x1b\xee\xe8\x8bl\xfd\xfe\x1d\xa0F*I\xc1\xc58\xff\x08\xb6v\xf3P\xe0\xbe-\xad\x92\x01\xd0\xf59g\xb1\x8a\xb3\xcb"0o\xbfS3\x90\x82W\x02\x8c@\xa7\x9a\xfd\x14\x16\xfe\xef\xf3D^\xbfT]'
        b'/\x13H\xca\xf2\xc6\xa3E_\xe3\xb4\xc5Z\r\x9e\xb4\xcb\x13\xc7\x04rX,x& US\xcf\x11O\x1f\x89\x8an\xf9\xf1\x08\xdaK\xef\xffI\x9c\x9f\xc0\xbf\xe1\xd6\xa9\x92\xe5\xdb\xf4O\x80\xb3\xda^\x9bPF\x8a~'
        b'\xdb>Zx\x1f>\x00\x82\xcb\xc6\x82\xbb\xadR0&\x8ax\xf76\x82\xd7\xac\xbdg\x8ao(\xefa\x03\xf8H\x8a\xbb\xf9\xf1\x935\xf88/\x85n\x98\xf1\xd1\xcd\x96\xe9A\t2\xa5\xeb8\xe0\xf6\xf4\xc0\xbc\x1e\x8f\x86'
        b'\x1d\xdd\xf2\x1e]\x0f<\xacir\xc7[\x840\x92\x8d\x02\x92\xbcr1W\xfd\xd7,7\xb6\xbb\xc0\xb7\xfd\xc6\x12\x902\x01\xc5u\xdf\xc1X\xe1\x16\x08\x19\xa0h\x85H\xb2,\x1d\x12`\x01\xa9\xb7\x83\x88!m\xf3S\x1b'
        b'\xe5\xc0w\xad\xb3\x0f\xd2\x91QTSx\x06\xc1\xd7\xaez\xbf\x12\x82\xb4)\x16l\xa6\xef\x0fGc\xf5F\xb3W\xa4\xb4k\x199!:%\xb8*D\xab\x9fn\x12\x1a\xf7jf7\xff\x9a\x14\x18\x96\x0cH\xf9\r\xd8t'
        b'\xbb\xa8(_H\x95R\xafj\x1f\xd1\xc2\xc3\x95\xe1xb\xcfnQm\xe0\xe7O\x15\x8e\x11\xa1\xee\xc0"\xb1\x06p\x13%\xeb{a\x93\x8e\xf3\xd8\x8f\xce\xf17\x85\x8c\xd1\xae\xd2\x80os\x89\xcf\xb2\x10nt\x08\x92\xd6'
        b'r\xe7\xb4\x85\x05e*2\xfc0\x17\x87\xe3@s\x02\x8d\x96\x16|\xec\xc0,\xb5\xd9\x9c\xe9\x1b\xf8y\xbc>\x85&\xa2\x11\xbe\xa5F\x02\xd3c\x19\x1e~\xeb\xe9g\x11q@W~\xcf\xbc\xb1Z\xa8\xba<\xa7\x12\x93\xd6'
        b"B\x12B\xff\x15\x8d\xe5\xe1*4b\xf8\x9c\x06qC\xc5\xa0F\xc2~^\x06\xd57\xa7\xb3\xa1\xf4\xb7i\xa0\xddJ}\x98G\xa5\x08$\xdf4\xae\x85^\xe3\xa7\xff'\xc23\xff\xef|R\x90f\x06\xfb\x9f\x0e\xfc\xc6\xb7"
        b"\x14\x87\xa1\xab\x08\xfb\xc3z\x12\xa6&\xa2\xddkj\xf1\xfc\\\x95\\\x85\x90\xeb\xbdM\xb7\xcc)\xe5\xd2\x9e#a\xa3\x979\xe4\xbf@\xdb\x18\x82C\xab\xa7N\xd12Is<'\xe1c\xdbG8U\xae\xe5\x0e\xd06\xc4"
        b'\xaf\xd9\x16\x19\xc7\x01i\x1f\x11\xe4\x85\x11E\x93-j]D"\xefUZ\xf7yi\xb1\xd1\xf4\x01\xefQ\xb4\xf2L\x9a\x82pm?Rm\x8euUbA\xb2\x87\x0f\xe0\x14S\xdc\xb4\x18\xec\x17\xf2\xd7S\x88\xa5)\x1a'
        b'U2\xe81\xa3m\xa2S\x01\x85\x81"}4\x0f.\xa0\x88\xa0h\x8cg\xd1\xa9\xbcz0pT:\xa4\xd2|\x16\xc8\xe9\xb6\xe4\xe8<x\xe5\x02\x8e\xda!3DRy\x079\xe9\x98;\x17\xf3\xb1\x12\xdc\xcb\xc7\xe5\x17'
        b'\x88\x9bF\xea&\xbf\x9b\xf1k,<\xd0\x1c\x7fcR\x87\xbc\xb2\xe5\xaf\x10\xe7QdR\xa2\xa6M<\xfa\r\x8f\xaf_\x84+\x936n\xd6\xe9\xbc\xfd\x92\xf5\xa6\x80A\x19\xce\xc1\xb4\xddq\x8c\x83\xc9.v\xba\x91\xe3\xa4'
        b'\xd5\x81\xc6R\x94\xcb\x81\xe7H\xbc\xa3l\x0b\xb6M\xbc$\xda\x92nBX\xef\x81\xc2\x7fO\x99\x06\xf1na\x88\xb2\x89\xd4\x06\\\x85\xbd-\xd2~\xb2|\xde\xa6q\xd3\n\x15\xecH\xf3\x11U\x8c\xd0\xde\x89\x11K\xb4\xbf'
        b'\xae\rn\xe8Y\x0e\xbc\x194\x03\x15e\xe8\xe9\xe6\xc9\x19o\xc9\xdb\xa52\xaf\r\x18\xf0(\x95\n\xe0\n\xcaoA\xab`\x18i\xe05iu\xfd\x92\xa6\xb1\xf2S\xcf=\x81(\xb8\xf7\x9e<\xebAZ`\xff\xf5\xec~'
        b'\xc6\x07\xbb\xf0\x136-rn\xe5S+\xda?_*\x1a\x855\xfe\xfc\x13\x03`W;\xecY\x81\n\x9b\x8a.\x19q\x15\xa8\xd78\x85\x81\xdf\x94$\x16,\xd8\xfeF\x02\xe5\x1e\x0c\x1d\xf8y\xa1$<i\xca\xaf\x9cY'
        b'DT:\xc8\xde\xc6\x06\xcc\x83s\xe2\xbb\xea\x8dj\x9a\xce\xd1\x94A$\xbd\xa8\xcf\\\x1d\xcd\xc4Z\xba5\xb0k\xc0l\x13\x9d`7r\xac\xf7\xf5.\xf8\x1b\x0e7WS\x9bH}_\xc4\xbc\x88\t\xe2=\x19\x94\x10\x99'
        b'+\xd6XYI\xcaz8\xd4\x89\xef\xce5\x02\x12\x87YF\xb7T\xbb\xcc\x95\xa4\x1c&\xc6\xb8\xd6\xb1aE\xaf:\x8e}\xa8\xbb?\x1b\xeb\xf1\xd5\xc7\x8f\xec\n\xda\xa5|Jw\xeb\r`\xf9\xb6\x01Hb\xa5\x031z'
        b'\'lV\xc3\x82\x16\x0e\xf7Ya\t\x8d*\xd8#+\x8d\xc7j\x96\x88\xd7%\x03\xbb;\xe0 P\xb0\xab*\x1d\xc8\xc3\xd5\x8e\xben\x19\x9f\xcdl0\xb9\xe9\x82\xd4\xc8\xd5\x88\xe8o|]N\x13\x9c\x91\xad"\xa0\x81\xad'
        b'\x1c 20\x0f^\xc9g\xd0.\xfa\x9b<K\x95A\xa1\xd9\xe3\xc4\xb7$\xb3X*\xa8\xefH\xc5\xe0\x08\x0e\x1a,\x1cm\xad9)\xd8Sy\x16\xcb\x12*ffW\x83\xee\xcf\x82"&\xc8\x7f\xd6\xc0\x12ul?\xad'
        b'm\xfe\\J\x84\xf9\xdbhlH\xdcY\xdd\xd9\xcd&\xa2\xbf\xa1\xd6q\xff\xe6\x1c\xa4\xe0\xbd3!\xd0|\xae\x9f\x04\x01\x19\xafU+\x1f\\\x8e\xd6\xce"\xf9\xcaX\xb3\x83W\xe4a\xe7EP\xb34\xdc/\xc4\xe0g\xc1'
        b'i@\xc4\xe4\x9e\\(\x8a\x16o\xd0\xa4\xa1\xb3\x83\xc7\xea\x1fS\xfd\x90\xc2A]\x91\xaby\x1b6\xa4\x10d\xedE\xfb\xb1.O\xb3Y\xc4\xbd\x08\xbb\x8f\x81\x83\x0f\xc7\xe7\xd9u\x0e\xe7\xaeGU\x84\x08\xb5S\xe7A\xf7'
        b'\xdc\x93\xabi7\xf3\xfbz>:\x98\xfcK\x81\x13(%2,Q\xbdDI"\x83\xf0\xc4/wk\xec#7.AvX\x11X\xf5\xa1\xd2\x1a\xfd5O!\xfa\xad\xb9oC\x8fC\x99\xe1\xb3,s\x06\x10\xc7\xb0\x81'
        b'\x7f\x84\x89\xbf2\xd7FT!\nj\xcc\x88\x08\xe0\x9aB0l\xb0\x83\xd6\xf9\x81\x90\xdf\xc1{\x12\xa2O\x81\x9a\x01\x9c\xfe\x1cW\x1b:\x06wu\x14V|\xb4\xda\x1b\x86\x80\xde)\xfea@\xfb\xd3\x92}tD\xadd'
        b'\x82\xeb\xe8i{\x05AN\xc8{\xa6lkg\x9f\x10\xf8\xbf\x13\x9d\xe7=\tno\xb9\xe1\xa9\x14\x1e\x12\x9f"\xe4T\xfe\x80\x16\x9d0/\xe5mX,\xc3"\xd4\x8d!4\xe2\x9d\r\x86!\x7f6\x99{\x13x\xeb\x83'
        b'\xda\xde\xbd\x16\xd0-\xd0\xa2\x0bp\x90\x9bga)\xd0\x88`\xad\xf4\xf7\xd6\x9a\x9c\x9f\x06\xac\x1a6\t\xff\x05\x1fU\x98E\xaa>\xd9\xc2\n\xab\x95dJ\xda\xaf\xb3\xdc\xcc\xa6\xfb\x03D\x8d&\xfa{\x0b\x8c\xeeN0\xda'
        b'A\xf0\xcf\x1b>c\x07N\x90\x8a_\x83\xe3\xe4\x8e\xdf<\xb9\xd0\xe8\xb8N\xd3[\x93\xa6\xec\x88\x8a\xda\xae?=n4\xd3>L"\xd9@P\x92`\xbd\x95\xd7\xc4&\xa0\xba\x0fT\x80E\x96\x147L\x02\xdc\xabK&'
        b"u\xbd\x1bet\xdc\x85\x81\x99\x97\xaa\x9d\xa6\xb5<}\x19\xc4\xe8dN\xf6\xdf\xe9\xc8\x7f\xb4\xf0\xff_\xb2\\\x06d\xd2\xa0\xd8\xd1\xa8\xe4\x96\x16\xfa{\xf8'\xf7\xdf\xbd*8\x9c[n<c\x19\x80\x96'\x17'\xb1}"
        b')\xccse4\xb5\xc0Xis\x04\xe8x\xdc\x0ca\xfb\x05\xfc\x8d\x1e\x83\x9aV\x81\xca\x94OSEb\xa4z\x17\x18\x03U\x88\xf2)\xe2t#\xa6\x89\x07\xb8\xaaz\xc6\xac\x8f\x07\xd6\x1f\xc8\xe3O\xf7\xaeq\x1f\x877'
        b'\xccJ)\xbf\x8c\x80j\xa3\xff\x00\x8b\x9c\xa6\xfd$\xea\x12\xb2\xad\xd7#\xaa\xc4h\xbc{\xbaD\x87\xba\xf0E\xc9\x92\xc5\xfd\xb5\xc1\x18\x88\xef\x81\x123i\x034$\xbe\xb7,\x94o\xd7\x99#\x81\x17\xad\xa4,\x02y\x97'
        b'9\xbf\x1d\x19\xe1\xd8?#\xeb\x1c*\x01g\xff\xda\x83p\r1\x93\xe8\xca^\xbcS\xea9r\xc6T\x8d<Y\xac\xd5\x86\x8b\x14\x1a\xe2\xc9\xf5\xd3\x01>~\xcdthnw\xedms\xa0\xe9p\xffQ*DM<\xa1'
        b'di\x1el\xb0\xc7^\xec\xd5\x7fQMs2\xf9O@\xb6\xd4\xb2\x00_\xc9\xbft\xccz\xcd\x9c\xafmS\x8c\x9f\x80\xa4\x87:0\xf4\\U\x85\x0b\xc1!\x0f\xd8\xf0\x8d\x82\xbd\xa7\xc8\x953\xba\xb8\xf5o\xf8\x1ak\x93'
        b'kGV#\x9a\xef&Z\xd1.\xef\xb6\x85\x14\x8d|\xce\xe5\x7f3\x02\xc8\x81\xa2\x05\xe5@\x9b\xee\x80\xd4M=#\xdd@\x1823\xa7\x98\xd9\ny\xce\x7fYvr\x83a2\x8f\x1a\xa4Q\x96\xef\x80\x14K\x08\xbe\xd8'
        b'\x12\xec1\x95\x8e:\xa1gOw\xb0\xa9\xf6Z\xa1\xde\xf8\xf2@\x9a(UL2-\nM\xcd\xafN\xf1\x8a\x9a\xf9\xc08\xd3P\xe2\xeb\x84\x015\xdd@\x17\xbdh\xbd\xd6\x0fdc\xb26>[\xea"h\xa8\x1f0\x18'
        b"xj\x1c\xa5B\xd0]=\xc4\xee\xb7\xfd\xe0k\x8c\x11\xb2'\xcc\xca$L\xf0\xea0\x99\n\x10D\xa5\xe3\xa3>o\xca\xbc\x0c\xadV\xf4\xb9(\x9d\xe5\xcf\xa1\\rZ\xfe\xde?\x81\xbc\x17W\xd6V\x93\x877\xf6y\x06"
        b'\xc94\xf3\x83\x01\x1d\x9c5^\xab`\xfa\x96\x8f\x87\x04\x82,M\xc2\xc9P7\x9d\x00\xd9Ps\xdaBc\xed\xd4\x0cT\xd4,\xefBh\xee_\xc6\xe7\x92\xe2\xd0|q!\xe1\xda\x1cKOC\xa9yl]\xdd\x95\x0e\x11'
        b'\xd6\'\x82L\x80\xa95\x92\x82\xaa\xcd\xff\x0fWp(,\xc1L\x12\xd4\x14 "SZ\xd9\xbdX\xee7\xd9\x0e\xeec\x97\xf3\x97.r\x11\xb0\xf2\x1b\xf1y\xc7\xd7\xda\x1db\xfe\xadP\xda\x99\xcdgf\xa7~\x88\x84\xd6'
        b"\xad\x03J\x02\xda\x8f\x9a\xc1\x1f\xd2\xad\x91\xa1\x1fQ\xa5'\x87\t\xae\x15V\x07\x0b\x867\xb5\xa9c\xb2y\x87\xe8u\x18\xf666\x08\xe9\x84\x002\xf6eT=\xeb\t\x97\xb6+\xc5\x8f\xfd\x14\xad\x87\xaf\x8f\x11\x9d\xc7h"
        b'J\xaf\xbb\x03\xd5\x06X\xeaVwe\x80[\xce\xb2\x80\xbf\xdd\x89\xbb\xdc\xd02\xe8\r\x18M\xd7\xba\x04\xf9\xe1\xa2,\x98\x87\n\xb1\xe8\xfc*\x1ef*\x13\x81\xbd\x00\x96g\xda\x8fM\x8a\x1cz\xe2\xe8\x11SS5<p'
        b"\x99\x10\xb6\xce\x854\xff\xb6\xad\x92\x83\xab\xcc\xef7\xdbngG\x06\xc0\xb2u~\x1e\x00\xed\x86Z\xa4\x17`\x1f\x8d\x8c'\x95\x0e\x96qKz\xf7\xe1\x08\xb0\x92\xc5\xaa\x16\x8f\x96\\\r~+\xfeov\xbe\x87p\xd6."
        b'\x15\xa0\rG\x89\xe8\x89\x0e\x14\xcc\xd3\x10@\xb9s2\x99J\x9b\x07\xed\xfdP\x99\x88\xd2_m\xcey\x0e\xb0\xbe\xd9\xb2)x!\t\x80N^\x8a\xf8\\p2\xa935R\xa71%\xd5-\xd8\x8c0\xf7Oap4'
        b'bjp\x821\xa5\rZ\r7P\xfc\xe9\xa7\xce\x16\r\x9b\x08\xd4\x02 {\xda\x8d.\x06\xfb\xb5~n\x1c\xe2\xfah\xc8\t\xf2\x96\x06\xb7\xd8\x95\x8eh\xfbH,?\x1f}o\x01\x829\xe1\xba6\xa0\xef\xdd}\x98\xd6'
        b'\xc0e3\x892\x0f \xe9\xb1H\xad\xc4\x11i\x8e\xcbL\xa0\xbbP\xdd\xba\x1c\x8a\xf8\x0e\x05\xca\xb3\xc5\xf3\xa7\x08h\xb9\x1eH`\x1d\xefX\x13\xd1\xd7\x10P\xe8\x92\xecD\xe8\x01\xa0\x92\xeb\xf1OU3\x1e\xe1x\x12\x0f'
        b'\xa2D~R\x94o\x12\xf0q\xab\xa5\xb5\xa5\xfc\x9f\xe2v\x95\x10\xb6=\x90\xd04\x93,3\xd1D~\xe1\x0f\x06k\r.Ss\xa1\xefH\x05\x04\\\xd1?"\xbex8?!a\xa1\xcb\x93Q\xc6)4e\xf7\x97q'
        b"\xbf\xc0\x88\xb3\xcc\x8d|\xbao\xd8O\x1d'W\x0b\xd0,cE\xab\xef\x03\x13A\xb6\x05\xe74\xa0\xab[\xf3(W\xd7\x17\xcftX}\x01\x87\xb9\x8b5\xf2\xa0\xbe\x89p\xbc\x1c\x1c\x9e&\x98\xa8\xe2\xbe:\xa2o\xeb\xdd"
        b'pO\x96{\x14Y\x1b\xa9T\xad.{8?H\xcf-\xd79g\x1b\xa6\xa7\xde!\xda\x99Nd[\x0f,hb\xd2\xc3cjE\xb1\xa7_r\tQ\x14\x9c\xf5O(\x9b\x06dC\x9fy\xcf\x97J\x04\xd3u+\x19'
        b"\xf1\x8f\x03\xb8\xb8\xf8\x110W>\xbf\xd2\xa4\x92+\x0f\xec=\x9d\x91\x8d|\x18\xf4\xdf\xddV'u\xb9\xa0\x03e\x89\xd9;\xad\x85\xf2\x04&)_9\x99\xf5\xc6\xd2\xf0[\xc2\xd5\xf7\x8f\x12\t\xf5\xb2\xe6\\\x1b>d\xd0"
        b'1X\x05[\xc67V\xd8\xdc\xe6\xc0\x06%J\xd3GcV\xf7te\xb4,\xe3u\x1b\x18\x9b\x88\x89\x0b\xe1\xf7\x03\xc7\x16\xdb\xdd{\x9e\xab\x7f\xbct2K*\xdf/W*\xfd\xf0\xfc\xef\x8f\xda\xbc\xa8\xa2\xd9k\xaf\x99'
        b"w\xd9\xb9;E\xac\xf3\x03\x998?\xde;\x83\x0bk\x7f\x1d\xfe\xc8{j\xe7\t\x0e\xde\x06.\x993I\x9f\xa5Z\xd8I\xa89\xce\xa31o\xf5\x86T\x83\xdf\xc6#\x9d'\xb1,\xd3w\xf6u\x04\x9d$U<\xb0%"
        b'\xe18\x15\xec>\xea\xf3!\xa5\xdb_\x9a\xbd\xe79\xea&\xeb\xde\x1a\x1a\xa2\xb75\xc8\xc3:\x0f\x93D\x84W\x05\xd9$\x05\x17\x9b,z\xc9(Ar\xc5\x169`\x14{5\xd1i\x17\xe0O\xa2\x81\x15\x8c\x1b+\xdb\xd2'
        b'\x84\\#\xbc\xda\xb8Y\xe0\x8dB\xab\xee)\xf9M*?(\x13\xb9YUB\x14\x9b\r\xc2\xbb\xb9\x81\xb7\xc3\x17\x93|%\x03\x13\x9d\xbe\xea\xce\xb4z\xf29\xa8HTw\xa3\x9c*\xc6\x0c\xc2\x8c{\xfb*\xb2t\xe1\xd3'
        b'!\x9c\xde\xf2\xa7\xc1\x08G\x83\x9e\xc8\x8f\n\xcb\xebN\x80\x91\xe0\xcf\x07\x03\xddSl\xbc\xb3\xb6#\\\x10\x9a\x0b\xd4L\xa8\xfftY\x97Xm\xec7\xeeTu/\xe8QY\xbc\xdb\xaa\xc0?\xbc\xe3H\xe5,\x9a\x93\xb7'
        b'y\x84<\xa5aG\x8cs\x1c1X\xd6V\xf3&\xe9`\xbfq|Uq\x9f\xe7\xc0\xe0i\xfebZM\x10\xda\xe3u\xe3!\x0e0\xc7>3\xfaL\xf9\x8d\x1d\x8c\xe0Un\xd9\x05\x81f\xd0\x8a\x0c\x1c\xa7\xca=j\x9f'
        b'\x8a\xe2\xb3m=P\xaf\x99fT\xc7\xbd\xda\xb9$\xcd\t0\x06\x08\xea\xaa\x802\xf7\x019<\x9f\x0ei\xc7\xea\x8d\x06)\x81\x04\xb9\\\xa5\xeeJ\xb4\xd4\x9b\xded\xfc\xed\xa8Em`^\xff\x8b\xa7h\xf5\xc0\xe3p\xea'
        b'\x8c\x83\xa4\xbb\xb0\x98\xfc\xf8\xc4xJ\xab\xf6\t*\xfb\xf1N\xdbm\xf6>\x1078\xd9cyf!\x84\xa2\xb050q\x94<3\x7f:\x983\xc1\xcb\xc0\xdc\x8f\x1dU\xd4\x1b\x8d\xd0\x87\xac\xc5\x89\xce\x85\x96\xe6\x86A'
        b'\x19\xaaJ\xdb}\x03\x8c\x00T\xcaM\xcb\xfa2\xee\xed_\x0cBtC\x9d\xaa\xe6\xe0\x08\xdcGj\x9df\xb0\xe8zy\xe2\xd68y\xc8p\x994\xdfxN\xea\xf4\x1e\xb2XH~qSh\xb0\x9d\xf0\xbc\x1f\xa5\x15\x11'
        b'\xd7\xe2zF6U\xab\xc5\x15./<\xf2?R\x0f\r\xec(\xcf\x9e\x04^\x95\xe9u\xb7\x97\xd8\xf1y\xfe\xebt>tWo\xb9m\x91!;\xeb\x7f\x9a_r\xf8\xd1\xd6\xc5\xfeo\x95\x0e\xc1`\xdfC[(jo'
        b'6R\xe0\xb4\xf3\x7f\xf6\x8fI)\xc4\xedr\x0f\x918\x000j.\x87\xf4B\xb3\x91[4( q\xee\xcc\xf9\xe5\x01\x0b5E\x95\xff\xc3\xf7\x01Vy\xdd\x97\x83g\xf25\xae{\xfbZ\tE4\xdfi\xffv\x0c\x0e'
        b"Y|\n\xa5\xe56\x82\xd2?\\\x96\x9a\xa7]&?/\xdbw\x01\xac\xb5\xec4\x8b\x7f\xef\x08\x96\x95%N\xf9\xa7\x95P\xbe'\xc5\xb6NK\x93^\xa9QP\xa4^\xa5w\x1e\xcd\xd3=\x93\x08\x11\x17A\xeel\xeeg"
        b'T*?\xd3\x07\xa9g\xe9\x94\x82&n$\xdeaL\xfa\xd5\xa4\x0f"h\xf7\xd1u\xee_\xc9\xe4|$\x1e4\xe2\x0e\xdd\x1eD4!\x0b,\x95A\xe5\xd8Ua\xd6\tXV\x12\x0es,f7\xe2>\x11\x02\x8c\xb8'
        b'\xfd8\xbfQ=\xb5\x13\xdd\xed\x10\xd2\xe0\x97Pg9\xb6\xe9\xc5&\xe1\x11\xc4O\xdf2\xdd\x1b\x02\xaf\xb9\x82=PN\xffL60\xcbY\xab\t\x97\x9dpaT=l\x84\x07\xeeX\x86\x15&.\xef\xfe\xa6\x17+f'
        b'tp\x91\xddaE?\xbf\xa9\x13=\rQ\xef!-nq\xb8\xa3\x9d^\xb9\xa1K\x96V\x8b\xc8$ \xf7{\xd1y\x8d#\x07+\xc9}>\xbd\x11\xf0.\x9d\xcb4\x9f\xee\xd7E\xbdR\xec\x7f\xf8\xf0x\xd4+R\n'
        b'B\xe3\xb4\xd3aD\x81\x17O\xc4\xad\xce\x1eF#\x90\x01M\xc4-L\xfa\x9ckq\xb8\xa6\xd9\xd4T4\xf5\xae\x94w\x03\x8cf\xb8Fi$\xa2\xb1\x921\xfb\xbdX`\xf7\xd3%\xac\xc0\x15CL}\xd9\xf6)\x03h'
        b"n\xdb=\x82\x93\xb35\xb2C_\n\x1d\xbe4ht\xe0Q\x18|aV\xdc\xc3\x85\x14\x17erG\x94S\xc1q\xffz\xef\x05'PY\x80\xc4\xbf\x05 \x03\xc4\x95\xe4\x99\x87\x1b\xe6\xd2\x11\x80\xffv;\xd2\n\x0f\xaa"
        b'@\xff\xcf\xab\xe61\x06\x84\xe7\xb1\xbb\x9c\xd3b\x08S\xf52\n\xa9\xce\x1c\xe4\xa7\nb\xb3\x0b\xd2\x0bz\xf7\x1dk\xa5\xb6 \x89\xfaY^\n\xc3\x81\xfe\xbcc\x84\xca\x19\x86\x16\r\x89\xd3\x9b\xcf\xd7\xcbI3\xf2\xa0r'
        b'Xi{e\x08\xa2\xbch\x8c \xc8\xd8\xbe\x90\xac\rq\x1a\xed\xaa\xc9l\xa9\xe3Y\x884\x8fp\x97\x83#&\x8c\xe6\x1e\xc1K\xc0\x17^\x1e\xe2\x0cY_\x9bM^qka?`\x0bF\xfa\xfd\xdaF\xe5\xa8\x84\xf4'
        b'\xb8\x0b=jjM\xb8\x1b\x91I\xe5\x84\xd7\xe7u\xf4\xba{\xb9\xaeJ\xe7<\xd8\x9b\x01\x98\x82\xe3\x95\xd3\xc7Yxc\x04\xbb\xaf=\xae!\x14\xf7\x9c\xaf\x92\xd3Vul\x15\xc5\xb8\xbf\x00\x10\x11\xa3\xd8\xa4\xefz"\xbf'
        b"z\x14\xe3:iQ5\x052l\xde{pt\x8e{$\x94\xc9\x13n\xb8\x8a/\xe4;'C\xefc\x91\xe8@\r^\x12\xc4\xa8\xf1M\xfc\xef\xe5S\xd4\n\x08\x0c\x0e_\xd7\xb8HxVm\xfb\xcf\xe8\xfa@xx\xa6"
        b'\x89\xf6\xdc\xcc\x9e\xf7M\xd7M\x9c\xe8\nW\xcf9"\xf2A\xbb\x95?kL\x08g\xfa\xb6X\xf2\xbe\xf0,\x03\x974\xfd\x0e\xdc\xa8\xed\xa4y\x19\xcfk\xb3\xb5`\xd7\xb9\xab++px1\x1f\x8f\xcd\r)\x98<~'
        b"3\xe0\xc3m\xbf\x13\xb2\x15\x05\xf2M\x9e\x17p\x9b\xcb\x1a\xae\xd24\xbf'cZ\xbe\xe6W\x05\xf2\x88N\x197*]\x17\xa8\xc24\x08\xe7hg\xebi\\-\xd2\x9d\\\x02\xcb:\xe6:\xcf\xdeo(;\x7f^\x07\xb6"
        b'\x00\xf8\xfd\x11\x9c\xad\xf9g)4^\x8e>\xf3\xc4Qb\x87\x07\x13\x9d\xf3*\xb9\x80\xa86E\xc6EI\xa0f\xfa\xae\xe09\xaa\x0c^\xdc\x89\x84\x97\xa2\xafZ\xfbh\xb5\x07\r\xae\xb4M\x104()\x1e\x14 \x0c\x10'
        b'Y2\xf1R\x142\xd7"02\x1c\x90p\xcb\xdc\x1e\xaf\xf4\xb1\x1b\xe3\x8d\xf3m\x03\x8d\xf8Ib\xf8\x1b\xe7\x0f8\xec2\xc3\xb0\xb8\xf6t;\x0c\xf8\xde|\r)$z5\xeb\x94V\xf82\xeb\x81\xa8\xa8\x8cZ8\x1d'
        b'\x19\x8d\x17\xcb(\xa3\x0fAA.\xcc\xeb\xbdF\x84\x10\x14Z\xb07VQ\xfc_+\xc5\xc1\xf4\x87~\xb4\x11\x8d^v\xe0\xa4\xda\xe5\xb3\xbcm\xc4\x00\xd8\xb5,\x7f\xca\xc2\rK\xf0Vr\xc8r\x96\x00\x1aF\xc8\xe8\x9c'
        b'\xe3\xdd\xf47\x8fpi\xfe\x02\xe2\t\x8a7\xe1\xf6:\xb6@\xb5 \xc1\xa3?h)\x03\xd1\x85#N\x9c\x02\xb5\x0b\xd1M^\x03\x0c\x97\x8e~>\xd2\xc6\xd9\x80\xee\x16\x17\x87\xbc\xb3\x93\xc15\xd6\xb8\x19o\xe4k\xf5\x1a'
        b'\x97\xf7c\\\xf6\x9c\x0fH\xaa\xe2\x82\x11p\xf6r\x97i"\xd9\x93\xcb\xcde\xbf\xc2\xa29\xe2\x90h\x83\xea\x9e\x99\xb1\x8f\xc7\xff\x04\xb4_\x98\xba\xff"\xdb\xe2\xd9@<\x02\x87\xf6E\x038)9(B\x85\\\x1dD'
        b'\xbbyf\x06\xf2\x8f\xf5\xe6\xfb9\x0f\xb1mv\xf8974\xee\x8a5\x8f\x15/\x8c\x94P\x17\x83\xaa\xe4>|>r\x04#s\x92k\xec(aDS\x8a2^\\\xe6\xab\x80\x1a\xc4|tZ>X\x95\x896\xfb\x05'
        b'U\x8e#}f\x99\xf1\xf8w\xe0\x18\xefH\xe7:\xb9A\xef\x91\xc0+\xef\x13\x15\xfd\xe82VK\xcf4\x95\xb9\xc3\xe8]U\t\\<\xd9$\xd7B\xbfw#\x06Oc\x9a\x18\xc5\xbc\x8e\xb7\x97\xa9\nf\xe9~\xaf\xfe'
        b"lF\x8c\xa9\xd3W\x1e\xfdY\xe2\x02\xd2x!\xe4\x81\xe4\xdd\x03XSuY'\xf6\x9bz>s\x89\xe4\xf0\x7fq\xeexd\xc6\x11\xd5!\xa0\xe0\xd3\xf4\xa0@\xd8\x99\x8d\xfb\\\xed\x1b\xb2\x86\xce\x15\x87\x92e\x11\xb5\x12"
        b'^\xfeD@-\xab\x0f\xe3\x99\x0f/\xe3\x1e,\xd7\x893\xc2\xd0$\xbf\xca\x02AXT\x00\xf6Ew/\xfcJL\x97|\xe3p5\xc3\xa7\x96BN\xb6:z\x84w\nA\xbc\xac\x0f\xcf\xa3P\xbfnXe\xb7S\x03'
        b'eo>n/\x92c\x1ap\xcc\xca>v\x1d@\xc2\xae\xb2D\xfa\x8c\xe5\xec\xb7\x86C$\xbf\x8c}\xd9\xc0\x81f\xf5m\x07?\xcd\xa0)\x95_"\xe4\xc3\x9a\x8c\x1e\xc3\xebk\xf46\x7f\x85\xb8\x8c\xdd<:!pr'
        b'\xd0\x9e\x85\x0f\x15\x16QI\xac\xc9{\xe4&\x95am \xa8\xf2\xe4\x1bn\x19u:G\xd4T\xaf\x18\x1c\xca\x18\x92\x15*v\x10\x98\xa6DQ\xe7\xa3\x98\xa6\xe0\x05\x9dX\x0fT\xb4\xc4\xbe<\x1ad\xdf\xcb\x8e\xce;;'
        b'\xc4\xed\x088\x0b/u{\x8cSG%\xfc\x8a\x12b\xa64\xea\x7f*\x15/;,#So\xcb_#\x80\x99\xc0\x00\xa8I\xf0\xac\xf2\xed\xc9(&$\x7f\x08\x0e\x0b\xe7X\xcb3A\xec\xd8\xa3=\xe4@6\xfa\x0f\x06'
        b'x\xac\x90C(\x9f#\xad\x1a\xd3\xea\xc8/\x8afy\xcbA\xd9\x86$\xc7Y\xd1\x0e\xa5\xecr\xab\x1c\xa3/f\x811\xeb\xc2\x9bCXp#\xf20\tNj\xeb\x0f\x9c\xcb\x14\xa6\xd0A3?]Pn\r\x12\x11x'
        b'\x13:\x9dR\x8b\x82+\xaa\xe1*\x19\x1f\xc3\xd7\xd4\xe2H\xe0~Cbx)\xa5,Fpa\xa9TW\n\x99\xf3\xbb\xe8\xcf3i\xd4C\xd5\x84\xa8\xael\x05~\xae\x1e\xb6\x92\x82\x88\x13\xff\x04\x91=rk\xe2\x80\x87'
        b"X(\xc7\xf6\x11\xc5\x1c\xe8qu\x99?\x15\xd9d&\xdf\xed\x92\xf4~\x08\xe7/1\xe0\xee\x9b'2a\xe3\x89]_A\x02\xaf\xb7\xed\xbd?\x86\xcf\xae#C_\xe6\x95q\xfb\xed\x9a\xa7\tG\xecX\xf7\x89h\xa2B"
        b"\xa9\x93\x93`||\x89\nvqR:\x9a\x83\xbe\xab\x98\xeeth\x84\xdf'\xfc\xaaX\x16\x07\x87z\x87#$&\x07tN4\xf1L\x8d\x8b\xc0\x90d\xdd\xedw\x16\xc8\xa3X\x9c\xaa5\xb0\x7fW;\x8ab\x9aTS"
        b'n\xf1\x8c5\x08\xed\xe5\xa2\xc9Fk\xc2Uc\x0e@;\xd4 \x1a\x06-\xee\xf3\xf9[\xea\x92q\xaa\xfd\xee\xc2(q\xa7\xc3\xe2\x07\x93*pJ\x0b\x85\xd7\xe6\x0fe\x85c \xe6\xe5\x1f\xb95\x8c\xaf\xa6\xcee>('
        b'\x05\x82\x8e\x8b<\x81P].UWU\xae\xeb\x00\x90k2v\xc0\xb5\xf4o\xd0\x89\x86I\xcb^\xd8\x17\xaam\xfa\xbb\xa0\xeb4\xeazP\x1dP\xb6\xb1r\x83G^/\xd9\x93\xfbnM\xe4\xde/S\xdb,\xe1`<'
        b'pZ\xa9\xb6\xc6\x90\xbf\xce\x9a\xd3\xfb\xc6\x93\x0cPk\xd9\x84\x98S\xf5:\xf1\xd3\x19\xba#+\x9f:\xb1\xd3\x06\xe2\x01\xa3\xa8\xdc\xf5\xcd\xf3\xa7P!\xdb\xaf\xed\xc1-\xec\x92\xc9\xd65\xebC\xda(D\x90\xf1\xe0.l'
        b'\xb8\x10\xf1\xe1\x94\x06\x97pL\xa5(4\xb3\xaf\xa5\x88\xff\xb5\x87N\xa0\xeeiC\x08k\x04\t\xfc\xf0\xb5\xa1\x81)\x8b\x8b\xa6\x92F\xafa\xc65\xb8\xc5\x891=&\xa9\\A\xb2~N8\xe4a\xd5\x11\x93\xa4\xaf\xe0'
        b'\x03\xecJ\xeb\x18u\xcdg\x93\xd5h\xf8H\xb2\xc7\xf1w"\xab\xfc\xcb\xfa0i7\x08\xdc%\x98\xac\xc5\xeb\n\xd95\\G\x92\xfd_\x92\xbd\xdc\xdb\xf7VP\x94\x00+\xfeI\x08\x06#W\xaf\xe6_g\xd4x\x12d'
        b'\xfe\x19\x106\x1e\x00B\x17\xc5\x06\x86\xac8!)\x07\xf8\xa4\xbd\xfc\xae\x87\xcb\xb3\x08\xdc)\xec\x12\xc3\x15\xf6\xd4G\x91\x1c\xcb\x9f`\xdb\x86y\x87\t\xb8\x1c\xc6\x94\x9b#\x1aN9r-[N\xee,\xfd\t\xd0\x8e>'
        b'\xd89s\xd9\x95\xce\x1f\x9d\xab\x83#\xb1\x02\xfe\xbaV\xe3\x0b"\x87]x\xdb\xc6\x18\xa2\xed\xc35\x0f\xc0\x0c\x19\x98\xa5~\xd7\x05\xd4H8\xa5\x15\x0f\xbe\x89L\xaf!\x8b\xb5\t*\xe1Y\xa5\xba\xa3\xf8\x99\x85G\xe4\xe5'
        b'\x923\xc0\xde]j@\xb3P\x8adU$Gy\x1d\x90\xeb\xbdr\xee\tt\x16`=\xa4\xdd5\xbf)?\x1b\xc3\x9e\x0e\x0e\xac\xbf\xc9D\x16\xe7\xd9\xdb\x8a\x92\x04\xad\x9b\xcb\xa3\x07R6\xec\x8b6\xa3\xf8\xc3x\x1c\x1f'
        b'\xa5 A\xcb\xa9I\x18\xef\xa6z\xb9m\xe8\xba\x07\x1c\xbe\x89\xd5KL\x11\xddg\xc9\xbda\x03~\xe5l\x81[\xd1\xffF\xd9\x0b^\x85\xb4\n\x94EX\xfa\xdf\xc7\x1dtR\xb9\x96\\\x06\xa2\x15=\xb8\xa0\xfc\x90\x8a\xec'
        b'\xda\xb2Q\x1d\r}\x19\x88y\x97\x98"\x17Lp\xa2\xb9\xfd\xc5z\xf5\x9c\xbc\x0c\x91O\x8d\x95\xddr\xf6\x1b\xd3\xf7\x14\x10\r\xf0\xb5[\xb2V)\xecF\xba\x15\x89\xd9C\xb8>\xa0\x81\xa8J}\x7f\xc0\xd7D/w\xf5'
        b"\xd5~\x8a\xe1\xec\x87i\x9e\x9b`\xeb\xc8\xab\xfd\xa7.j\xe1\x9aa\x05\xcd\x92\x07\x19@\xe2[&\x06e\xd3\x05\x8e\xb1\xcf\xfe\xe24\xf8\x88\x9fy\xc7\x8fo\x1eo`~\x94u?\xce\xf6V#\xd0\x95\xeb\xa5'\x04\x1c"
        b"#\xc8}]e\xfa\xd9Y>^yspSl\xbd\x8a\x8c\xf8\x995\x00\x18\x88\x86\x8cNx\xbe\x90f\xfa\xe1\xe7\x91\xac\xf3m\xe0.i-\x96WG\xc2\xaa\xae\xfa\xcd\xd5\x87'q_\xf3^H?\nvK\xcf\x86"
        b'\xd4\x91\x0f\x85\x7fp\xddD\x13\xb0\xff\xd8\r\xd5\x97\xa0|;\xa0\xa8\x99\x93\x8bH\xec"=\xa9\xd5\xb4\xd8\xc4\x19\xffT5x\xd4F\xd5\x95-\xe6\xda<\x06C\xa0\xba\x86u\x1bT\x8d\x83\x13\xea\xd7\xdf\xcaSL\x82E'
        b'\x13?\x83\xf9\xcd\x8b\xa9\xc8\x96\x02\x06\x8c\xd9\x9f1Mk\xe5\xd2\x161eO\xcbxE\x89EY\x9c\xa8\xf7q(\xc8\x94\x1a\xe2\xb4\x1c\x8c&\xf69\xe7#+\xb1\x04\xa1\x9e"\xab\xa9\xe5\xfd\xe1\x15\xfb\x00+i%K'
        b'\xb0?\xac\xd7"|#\n\x1d\xd4,\xb4\xb6\xdf\xde\xd7\xd7\xbba\xf6\xea\xcd\xfd*\x040\xde\xca\x9c\xbf\xee>\xa4-\xaaQ\xe4\xbb\xf9\x9f1\x08o\xf6\x88\x01\xb7\xf5\xac\xdd\x86%\xce\xb2\x88\r\xe8\x84]\xd5D\xa3\xd4\xee'
        b'<:\xf8\x96\xe5\x07\xc4\x12\xb1\x8c\xed\r\x8c\x97\x08B\x8ek\x96\xb0\x13\x91\xa0\x02\xc1l\x9e\xbe\xb0i\x87(\x96\xa4>yJ\xdb~\xdd\x0ew\x9d\xea\xea\xed\x14\t\xe8\xfd\xcb\x81v\x80\x11\xaf\x9a\xe9\xbaXP\xaf\xe6\xf5'
        b'\xbb\xbb"\xaa\xe4\xcf\xa9&5\x0b\xa7\xe2\xb2\xac\xf2\xcdU\xe9EC\x0bq`\xa1\x8a\xb8Q\x87\x9dK\xcc\xb99\xa3M\x9e\x8d/W#g{\x83\x0ep\xab\xca\x1av\xcd\xcf\x1fS\xd4\x11\x16\xd7\xa11\x8c\x1b\xb6v~'
        b'\xc7\xd5\x8c{\x95fJ\x8b\xb8C\xc5w\xbf\xe8:Rr\x039\xf9w\x91\xb30\x9b\xb8\xe7\x82xo"\xaf\x08\xfc\x1f\x80E\xa9\xe5\xb7\xdcm\xa1K\xc2i\xc0*J\xa1\xafWaN\x03\x92J\xd0j\xcd\x19\xb61\\'
        b'\x94\x90\xd8(\xe5\x05\x19\xc8\xab~\xe5{T\xda\xd6A?\xaaX\x16\xd3\xc1\xe2\x9bxO\xcf\x04w\xed\xee\xac\xaa\x1f\xe3D\x04K1\r\xef\xfdw\xa1\xe5lU\xa2%\r#\xf0\xc7R\xd7\xc4G\xa2g2\xc5X\xce.'
        b'x0\xb7rl\xd3X\xaa\xf9\xf6\x8b\x92\x88JV\xe7\xa2\xc8\x82\x7fV\x1ch\xbd\x99\xca\x00\x84\xa8\xe8\r\x15\xa9 "\x0c\xc9\xa4\x9bH\x0f\xfe6\x01\xd3=Q\x82\x1a\xb9\x90\xb6\xed@(\xbf\xa6RA\x8f\xf3+xb'
        b'\x87\xd4/jk\x96\x0c\x9f\x16x\xe8o>\xd7K\x03w-\xa6R\x14\xe1^\xd3\xd2\xd4\xe9\x82\x84\xbf\xc0\xf3\xd6\xb3\\\x8b\xec\xd1<\x8a\xbb\x18q\xcb\x17\xae;2\x13z\x950\x0bWM\xe2\xee\x8aQ\xafp\xcb\x7f\xbe'
        b'\x0fU>!\xe7`6\x94\xd36\xc2\\\xac\xebOB\xa0o\xd8\xe2`\xaf\x85x?"\x0b}y8zF\x1d\xeb\xa4Y\x1d{Zn\xbb\x90R\x98\xbf\x04\xbb\'@\xef\xbe~\xb0!jJ\x04D\xc8\x99\x9aG\xb4\xa4'
        b'*6\t\x9a\x16\x1b\xdd\x0f\x9f?\x97\x06\x18\xa1^\xd7\x97p\xd7\x97\xb7\x15&\xe0\xd8ZW\xe0V\xe7\x06\xad\xb0\xd6\xea\x9f3q\t\xc5\xe0c2\xc5Ri\xd5]_dtI;e\x07\xacS[\xdf79\xa6\n\xdb'
        b"\xdb;FT\xf1\x0b\x8c\x91{\x12jC\xd4\xe89w\xe9lI7z\xfc,\xb1\x86&\x9fS)rS\xf2.\xbah\xc4'\xabX\xb8;\xbd\xb2\xa8\xa9\xca\x9f~{\xa7d/\t3\x8cV\xb4\xc2*\xba\xbe\x1b\x95\x1c"
        b"\x9f6\xbd\xf3\xb2\xb9\x1e_W\xdf>\xd1=\tJ\x16\xdf_\x18S\xdfB\xda'\\h\x84+\xe2er\xe1Xc\xbf\xe4|n\xadZ\xcb\x0b\xa0\xd6\x87\x86\xe6\xb6\xa2`A\xcf\xd1F:\xd7\xe9o\xb3\xf0\xe6\xb4\xaf\xed"
        b'$\x90\x05\x07\x93>\\\x8c\x07"+\xdd\x83-\xd2\xce\xd8\xe8g\xb1%\xcb\xf0\xdb\xc21u0\xcce\x04X\xf0\x03|\xe2\x87\xb2\xd6\x94\x834k1F\xf4\xa6?yvn@9\xfc)\x93\xc7\xc6\x1ay\xfd\xde\xac>'
        b'\xec8\xcf\x1d\x1f\x80\x12\xca\x9c\x15Q\xda\x13\xa7\x83\x83X\x07J\xd7\x9e\xf7m\x10\xf8\xc7p\xbe\xeek \xda\xd8\x97D\xaf?:\xae\xbd\x12y\x93\x03\xbc\xbb\xdd\x93@\x80<\x8f\x7f\xdc\xdf\x9b\xd0\xfa\xc0\xaa\x97\t9S'
        b'\x1eU\x12\x84\xff\xb6cb\xb1;S?\xd7E\x10t\xcc\xba\xdaeb\n\xb6\xe8r9vp\xf8u\x11X\xebI%\x04\x1b\xc8[\x10\xe6z\t;\x99\x1f\n^\xe56\x00\xa9\x92\xb0e\xdd\xb4\xeaH\xa3\x10D\x04\x82'
        b'\xeb+NvN*\x0b\xb5`\xdf%\x0c\xd2z\x7f\x9a\xde\x1f\xea\x0bR\xb5Aq\x80\x83\x02\x9a|\xbd\x12\xefar\x82\x81k\x1b\xe1|\xe7kQ\x19\xd3q\x92Fu\xf4M\xe9\xa9\xdd\xabv\xb3\x9dZm\xa7\x81\xe0\x10'
        b'Kf/^\x1aB\xe1j\xdc2X\x1dN\x0e.\x8f\xca\xf0y|\xe9!\xb31\xd1\xde\xb9\xcf4:\x89j_\xfa\xb1s\x9a\xc4\xdf\x9e\xd8o^i\x93w\xe0\xfbA\xa43\xdb\x0f\xe7^~QO\x08\xfeK\xbb\xec\xa9'
        b'\xe9\\f\xea1\x99\x0c!>\xba \x99\xb3A\x87\x15G\xf8c\x88\t\xcc\xaaD\xddi\xf0\x91\xb0m*l\x13"\x95\x03\xf6\xd1\xb4\xec\x11\xc5\x8b\xa4fPw\xc3\xad\xc65\x00s\x80\x9f\x04\xe1\xab\xd22\xe2 \xf9:'
        b'X\xb2\xa3\xf3\xf0o\xbf\xc2\xd8\x87b29c\xf5\xf7cl\xd9ok\xef\x8e\x0f\xa9\xea\xc6\x06\x87\x1f>r3\\\xf0?:\x05k\xc5\x1c\x86(\x1b]\xa0\xde \x9c\xd6\x18\xa9\t\xb1y{/8\x07t\x9cX\xaa\x9d'
        b',G\xcd~\x0b\x05"^\xe3|#?\x88H\x17`\x12\x16\xe5\xa5id\x89\x01\xb9\x16;AB]t\xf6Gj\x84\xbc\xf0\xaa\'i\xb5I!\xe3\xff\xa7\xf4\x89\x15x\xad\\0\xd1G\xdd\xea\x9b\xf5\xd7\x16\x0b\x0e\xd8'
        b':\xe3\x16\xa2\xba\x86\xd2\x02\xf8\xc6@ S\xd7y\x0e\x17\xbb]\xa2\x02\xb3\xf9\x04w}\x8d\x9a\xca\x01\xc2\xde\x0c+\x1e\x90u\xa5\x87wp\x94\xc4\x9fd\xce\x1a\xd9\xb7t\xc1\xfd\xa4\x91fA|\xfb\xc4\t\xca\xde*>'
        b'\xa4;E\x9d\xc7\x9b\x1c@\xf3\xaaU;\x1c2\xd4,{\xb5\xd3\xb1C!z\xeeRb\xa4\xfa>${\x8f\x0b\xb4B\x1b\x05\x8a\xc5\xc8\x8bx5\x1bn\xa8\xe7\xef9V\xa2\x82\xc4\x9d/LX\x7f\xcb\xf8\x92\x17p,'
        b'\xa5\x8b\xaaq\xfd4\x8f_2\x17>\x83\xd1\xef\x11l\xfbq\xf3\xbcl\xc1\xc3~>\x97r\xe8\x94\xec\x1d\x13\x05/\xe8\x8a(\xed\xe6\x84\xbd^\x87\xc7\xcf\xdb\t\xec\xffW\xaah\xaan*O\xfem#\xbf^\xd2\x904'
        b'\xbc\x86\xa8e\xe9\x0f&9b\xb5\xf2\xa4\x11v\xdf,\xbb\x0cX@\xbd\xcf\r>\x7f\xa2\xebZ(5<l\xe9\x7f\x92\xfe\xa5\xc7n\xe9\xeeDj\xe1\x89T\x01mk/\xe9DC\xa7.\xb7\xf9\xda\xf463\x10/\xb2'
        b'_lC\xa6\x9a\x92o<?\xb6\xffgc=\x12Z\r\x15W\xe7\x9cT\x823\xd2\xd8\x8c\xc9\x0f\x9aZ\x1f%\xde\x878\x90\x96p`[\xea\xf3O\x9e\x02\x7fLJ\xf6{<1[\xe5a\xe9\xe75%\xff\xf2p\xb2'
        b'\xf8H\x98NH8}@\xa7\xf1\xdb\x8f\xa0l9,\xab<\x88\x05Ai2\x10b\xa4\x82\x04\xe7"\x10o\xc7\xc5\x88\xd8\rM\x05\xe0L_F+\x18\xc5\xc9_5\x17\x9e\xc6\xba\xd0\x0b\x90g}\xec\xd3\xac\xc9\x88$'
        b'\xb8\x03\xf5\x9cq\xb1\xfc\xf0\xfc\x8d\x9dU\x13Q:\x9b\xa1X0\xb6\x95\x98=q\x92\xd2\xce\xed\x94s\xd5naa.C\xc6s&\x05\x9c\xe9\xd7\x1a\xea\x10p\xdd\xd2\xaf\xdc\xb9\x07\x10\xd4\x90\x9b\x83\x7f\xc2y]e\xd8'
        b'e5\xed%7\xb0\x86X\x18`\x9dX\xe7\xc5\x134\xe9\xcf\x03$#\xec\xe9\xd1\x82\xc7w\xc6]=/\x8d\x1a\xff3\x056\x0e\x14c\xf2b\xf9\xac\xc9j\xe4E\x85ta\xdf=\t_\x88\t\xb2\x88P\xa9~\xe5V'
        b'\x0c\xba\xa7\xf1\x00\x1d`\xe7\xc0\x1cv\xfa\xaah\x99Z6\xf4\xb9\xba9G;8h\xcaZ\xa7/\x1e\x88C\xafh\x05\xcce\xc9\xb1_\xe5g\xdc\xf2\x1f\x17\xeb\xc1z\xaa\xdaP\xbb\xfc\x1c\xcb\x02\x05J\xe0\xbc\xd0\xa2/'
        b'\xc4M#\xadq"\x80*\xf8\xd6\xcb=AN\xa3\x10\x02I\x15\xaa(\x10\x16\xf7u\xfb\x8e\xb4\xe4\x89\x91md\xb1}2`\xa2k\xb5k\x93\xc7l:\xe2\xa0\xa1!\xac`\x0c\xa3\x93\xe9\xd296??\x8c7\x07\x89'
        b'8\x0cJ\x96\xd5L7g5\xce\xc4\xf0;q}\xf0\xcd\xf3 \xe7\xbf\x90)\xa3\t\xaa\x9f\xa1F\xcfJ*\x80\xd0\x12\xf5\x92\xdd.\x9a\xbc\xbe\xdf\x84q\xb5\xa4\x12\x9d-\xa5\x1d\xdd\x94Y\xae\xf4 \xd8I\x07N\x00}'
        b"\x80\xe5\xc9XA\xd4\x95\xefMIc\x91F\xdd{\xa4\xde\x04\xbe\xd5\xd5Cp\xd01\x8d\x08\xd5\r\x0bu\xcd3e\\ \rn\xd0:\x81 \x0b\xb5\x7fD\xac\xb6\xe2'l\x93\xea\x8d\xd4\xd6\x7f\xae\xf5\x8a\xf37N\x08"
        b'^!\xc4u\x05N \xc2^w\x84\xa0\t\xf9\x00\xd0|x\x81^\x9d\xa0\x14\xff\x9c\xe6\xc0\xf9\xc5H\xb7iP\xfe\x13\x8fn\xf1\x8d\xe8\xce,\xb4\xb8k|,Vg\xcf\xe4\xaa\xd9\x9aE\xb5\x93\xc7\xc9\x949\xd1O@'
        b"\xbc\xbbZ\xf5x\xae\x9a\x91\xc0\xc6hp\xb1\xf3\x8b\x1cA8\xcd\xe3\x14\x87\x08\x0f4\xe1(\xf0\x06_H\xd2\xefb\xab\xc1*\xeb\xfd\x003V\x87\xcb\x13!\x8c\xa6\xcdF\x83,t\xcd\xb8\xb7\xaa}\xb4\xb4Xg\x7f'"
        b'\xe6\xf6Y\x14D\\\xa9`\x07\xf4\xcc\xe1\xe1$\x7f\xe2j\xee\xa7\x05\x98\xc4\xf0=\xa8\xa9\xa7I\xfc~\x00=q\xad2]9\xe5\xd5\xfa[\xf7\x97\xda\xc9\xcb8\x90O\xce\x1bJ{\\\xca|/?\x80\xe0\xe7\xf3\xc9p'
        b'\xa5\xb4[\xfeT\xb0|\xe9\xb4y\x9d\xff\xcc\xe2"t|%\xf8\xab\xe8\xcac\xb2\x8d\xb1\xdb\x10\x03\xc7n\x16&`\x0f\xf1 \xe1_\tp\x98D\x87G,\xe9\x9b\x0fy\x88c\xb4\x02\xd7u9\x1eU\x16u\xfc1}'
        b"f\xb59\x02\x93\xe1\xc9V+\xcf\xa8SlUGC\xbc-\x92$\x98\xee\x88\xb1=\riw\xc2\xe7j\xd4\x88\xca\xa8\x1a:m$\x18r8\xe8\xbc\xbd|R$\x82\xb9\x92'\xff;h\r\x163\x13r\xaeY\xc8\xec"
        b'\x04\x9f\xdamx\x03\xa7\x8e\xd9\xa0|\xb3\xe9\x8e\x1f\x82QxDr\x88@\xe9\xb2\xe7\x8d\x8b\x11\x8e\xc3kf\x8fn\x08\xe9\xa7b\t\xb2)\xbbXOd#\xfa\xd7\x17\xdae\x18\x7f**2\x17>\xd5\xf0\x02N_u'
        b'\xd4E\xf1\x7f}3\xe7L\x93\x93\xea\xd4\xcd\x0e>\x92C\xc8\xd70\x1b\xbe\x87\xc7\xc5\x18\x92)\xfa\xe92\xcf\xa5\xc3L\x98\x83\xb2\xba\xe1\xeb\x95E"\x84\xa1\x81\x9a\xfc\xbbN\xc7o\x95\x96\xdb\\\x95\x02!\xdc\xa5D\xe6'
        b'P\x99;.\xff{n\xb0:\xe4\xec"\x86#J\xf3f\xd3!V\xc9\xe743a\xfe_\xd29g\xab\x82}\xd2\'\xf8\x06\x01u\xda\xe1]\x07\x06Rj\xc7\xe2\xa8}6\xbe/Dw\xb7:\xbd\xea\xc4\x88\x9eB\xf8'
        b"\x8e\x15:\x07\xb8\x9e,\xc8\xb8s\x82\x8c\xdc>_(\xb2\xdf\x19W\x0b\xf4\xac>\xe7\xa5%\xfcJ]\x16H\x9c\xcfx\xcf\r\xbd\xa7\xfa\xe6S\x1a\x11\xa0c\xef\x07;\xa0\x06}d\xbciM'#\x07j4\x9bI\x86"
        b"B\xf0\x17D\x91\xbb\xf2&\xe3en\xd4o\x04\xd5\x81h\x04\xcaX\xee\xb4\xca\xd9\x9b\x01\x9b3go\x93\x15Aj\xb42q\xea\xa5\xe8!f\xe5m\xd0\xefu'u\x10)>\x14\x894\x9a\x86\xf0\x93p~As\xd4"
        b'\xaa\x91\xfd\x19\x05O\xd9\xca\xfa\xc5\xbe&\xdfjF\x8cD\x9f\xa39/\x08\xab\x015\x0c90a\xa3H\xa3\xce\x8csV\x1c\x92S\xd0\x8c\x84\xd1\x0f\x1b\x7f\xadOA\xe3s\xfbbIj1g\x9c[^?T\x0b\xec'
        b'P\x94m\xb1\x126l\x88\xbcK\x80\xd8\xe5\x15\x88\xc9\xa2\x88~\x1e\x96i\x80\xda\x05\xed\xedE\t\x9bh)K\xd0\xf2SF\xa3Z\xd8\x95\xe5\xce\xbd\x04\x13\x91\xd2\x9dtP\t\xe6\xfc\xcf\xbcy\xa7\xea\xbfM\xa2\xf8M'
        b"^\xdcc\x0b\xef\x87\xe9\x9f\t\xfa\x02\x7f\x9cb=m\xfd\xf1\x17t>\x18\x98\xda\x19`\xa7\xdf\xd7\xf7\x11\xd7m\x0c\xd2s\xf8\xb4\xa2F/\xa6G\xfd\xb3\xce\xef\xa1\xf9\x10r\xb6'7i\xe6\xf5\xcf\x8c7\x11\xcer\x8b"
        b"\xc8\x13\x01\r\xcd\xfaZ\xedoze\xacNw\xab\xbb\xaavF\x0bY\xc6\xf4\x9c\x8e\xb6\xf5:\xcb\x86\xec\xb4'\xc1\xaa9i.xM\xf2\x99ps\xf0\xf0\xa3\x8ef\xbc3\xc4OD#\x9c_\xaf6\xb2B\rvK"
        b'\x92\xb5|\xf3\xdc\x8a\xca_\x87\xf2%\xd0\x9b\x90\xeewrA\'k\x1a\xd75\xe6x\x8e\x99n{9\xd8]\x03\x17\xf5"y\x07a<2\xdaHk\x16R\xde\xe3\xdaE\xder\x00\x01\x96B\xfe[53s3\xbb`'
        b'\xa7\x16\x1a\xa1\x1cY8\xafKz\xff\xd2x5\xc7Pi\x8bY\x93\x91\xfe\xda=`\xa4\xb8\x85\xdf.\xa9u\x1fB\xd0\xff\x99Tce\x80\x0b\x8b\xb4\xa0?Q+\xe4\xc5%f\x03Mv\x7fLY|\xcd\xf1\xc9;x'
        b'\\\x9c\x7f\x0b\x03|\xd9\xf5|>\x89\x8f4\x97\x1c5\xdd4\xa8\xf5\xa7\xb2;\x04\xbc\x1a\tW}\xaa{5+\xa4*9\xfa\xb1_Y{!\xc4U{(\xe4,\xe7\x17v(F\xe7c?\xact\xd9\x89\x7f~\xcer'
        b'\x85\xe0\xe9\xea\xcc\x8aa\xbd\xdfG\x86\xb4\x94@&L\xd1\x7f\xffv\x05\x12\xbe\xd6G%~\n8+f\r\xfdD\x9cM\xf8\x82V\xc1E]\x8d\xba\xe3o\xd9\xb4\xbe~\xba~\x02\xc9\x8d\xd6t\xff\x01\x80$\xca\xad\xa9'
        b'O\x93f\xc7\xa9\xe2(\xff\x0f\x93Z\xc4|\x9c\x02]\x08[A\x8d\xf4\x9d%?\x13\x077\xdc\x96\xb5<H\xa4\xdde\x03\xf3mT\x13R\xa6\x08\xbe\x8b)\x13\x12;\x8c\xc4uQ:\x06\x00U\xd19\xaa\xfa\x95\xe8\x1a'
        b'\xba\x14\x9f\x1d\xd5\xf6x]\x13\xbd\x8b\xa3\xb4\xae$uM\x05\xe7\xe8Z\xb0w\xb7\xd0\xc5k\nn\x8e\xb4\xfc\xfb\xfc\xe8\xcb+\xe7n\xdaP\xf0\x8e\x17\xa0\xa1\xcb`\xf6lf\x065[\xd0\x93\xa4;\xe9\x07\xd2}\n\xab'
        b'\xd3\xa6\xcb\xae\xb2\xba\x18Q?\xb3\xef\xc6m2q\xd9\x88\x91\x8dz\xc3\xbb\xfd!\xd2Wc\xd8~oM\xeb\xb5\xb0\xf7\xf0q\xe0D\xf5\x91B\xe5{\x9d\xed3\xf15\xe0\x88\x12\x14\x10\x0e-\xfc2U\xe7\xa9\xa5\x0e\x86'
        b"I\r\xf9$\xadO=\x8a\xf18`M\xb2\xa5\xfa\xd9\xea\xa8+ \xbc\xfa\xb9{.A\xdd\x8bR\xe3\xa1\x13\x82y\xb90S\xbdNz\x9e*\xe5\xfe\xe5\x95\xe6L%J\x12\xdawu\xa1'\xb1\xfd\x0c'\xda\xa8^O"
        b'"\n\xbb\x828Wu\x8b\xd5\'\xa33\x99\xde\xe5\xc8\xb7l8h)\xf3\x86L\x81\x8b\xb8\x85\xba\x82\xf9\x93e\xebD\xea\xfcx\x95F\xef\xafDoc#\xeer\xd7\xc6\xb6P\xa5<\xcc\xd6W5\x16jBl.\x83'
        b'\x02"-\x9c\xf7Z<UR\x1c\x8a\t\xf9\xeb+\xf0]\xba\x01\xb6 Cp\xd8\xe8\x17)\xa3C(p \x1a\x92\x94^\xed:\x08b\'w\xe6\xb2C%\xf7\x80\xbf\xf0I\\@\xed\xfb}~^\x86y\xf7D\xaeP'
        b'zO_\x00\x05kE\xdcYfZ0#\xb6\xd8j\xea\x18gD\xff?\xfc\x1e\xff\xddt\xd9\x1a\x87\n\xb8\xf9t\xf5\x1a\xe4\x18\xacWb\xc5\xb5\xf3\xb2\xaa\xa1\x9d\xfd\xdc\x95\x82m`\x1c\x9b\\E\x85A\xfd\rp\xc1'
        b'^S\x8d\xc4g\xf4\xdf\x87C\xae\xee\xcf\xea\xae\xdfs>J\xa6\xd6v\xd9\xd1\xc6^\xab*\xa5m%\xc5jC\x12\x13\xc5\xb3\x98\xc2;\x0f\xd4D\x10[X\xb5\xad\xca,\x03"\xca;I\xab\xef\x8cz\xf1j\x95Y\xf5'
        b'\x9e\xfa\xee\xdb/\x8f!\x1a\xc0\xf6\xac\xa9\xba\xba\xe3\x1a\x8bz!\xf6e\xe1\xb3\x8f\xf0]\x07R=\x12\xc1\x7f\xfbx\xc5,\'\xa5J \x90\x8a?\xb1$j\xe0\x95\xcf"\x99\x93~\xbd\xe0\xb0\xbe\xc4\xe5q\xde&\x0b\xb6'
        b'\xba\x08.1\xab\x1d\xd6\xd5\xd9z\xc7\xdd\x19\xf9K\xe8\x0e\xad\x04\xd2fA\x94P\x12j\x1f-\xb6\x0e\xd8<!A\xe3\xb6=Y\xd6\x8c\n\xe6\x07\xa9\xf8\xa2\xf0S\xe99\xf1\x83\xf6\x89o\x02\xfd\xf0\xba\x17\x91\xa8[!'
        b';\xda\xe9\xcd\xbdw\x19u\x13PS\xa1m\x04\x88T^@\xa3.\x079\xac);Yh\xa1\x1c\x8e\xefc\xf1\xf6A\xec\x86\xb4\x9d\xe6\x15\x91\xcbq=u*\xdb\xb0T\xd3Ynzn\xb7k(9u\x1fH\x89\x16'
        b'/\xa7\xfe<\xda0mxN1\x0bO\t\xad\xb2\xac\x80\xae#\xf9K4o\xee\xfa\x00\x02T\xcf\xf0k\x17V\nm\xc0\xec\x1e\xb8\xd0\xca\xec\x11qe\xe9Fo\xccOpg"\x9e\xb6\xc4j3\x93;\xe9%\xf1\xbb'
        b'\xd0\x0f{\x8f\x99N\xab\xaa.\xb9\xcc\xca\\\xa4D\x93\xb6\x07\xa4a:\xb4sn%\xe2M\x9d\xfd+\xb6>|8\xaa\x1dW\x08\x16\x80\x9aFp=\x96"\xe29\xc0\xd6\xebuN\x8e!\x94.\x9b\xf5~!U\xca\xf5'
        b'\\|\xff\xbfG\xbd\x05\x86+\xe6\xad\xdf\xd1\xea%,\xc9z%\x92\xb3\x9d\x1d\xa8?\xce\x1e\x0f\xe6\xd7y\x9b\xbe\xf8\x8fb\xd6s\x94\xac\xe9\x16\xc9\xbb\x83\x8aK\x02\x7f6\xe8*\xbf\x03\x01Vo\xc5|\xfb\xed\xcb\xe9\xd7'
        b'\x9b[Zn\xd6\x12\xafTo=-\xee\x0b\xd9\xfa-\xaf\x93\xb3\xe0qq\xf8\x83\xa10\x95b\xe1\xc7\xd3\xdaR\x95\x86\xa7s\xb3\x91?s[T\x0f\x98u}\xebW\xa3\x84\\\x8cZR\xdf\x0f\xc1q\xf1\xceW4\x87'
        b'\xff&cGC\x94 o\xe9\x05\xd8\xb0\x170\xab\x88\x14\xef\xb6N\xe3\xe1\xb7\xa2\xceq\xa6#g!\xda\x9a\xd1\x87\xf8\x8c\x82\xe5\xe2\x95KM\xc5w$\xb3\x80\xfc\xbd\xc6\xf3~\xaeY\x98\xff\x17"u{\xa0\xda\xb3a'
        b'N^\x87\xae\xe9\x96v\x94s\xd5\xfc\x13\xac{,\xd8DZ\xbc\xf9\xb9GC\xaa\x05p<9\xd3\x92\xec\xdf\x179\x8ew\xea\x9d|\x99\x8d\xfc^\xb6P\xe4i\x859\x9f\x12\xad-\x8b\x91\xf2G\x05\x9eu\x93\xb7OC'
        b'\xa7#\x19\x8c9\x1d\xb3z\xdf\x95\x8bn\x8b\xefC\x99\xb03\\\xa8\x9a\\\xc5.\xacsx{\x85\xa1\xa0# >p"<\x9e\x97\x86\x9bl\xb6<\xa1p}bb\xf4~\x8e\xff\xfa( \xb82\xda!\xd0\x9cSB'
        b'\x8b\xc3j\xd2\x0b\x00\xe0\xb5M\x03#$\xf8\xc4\xa0\xf0\x95\xce\x1c\xa6\x98\x05\x12\x90s2\x98\xdeg\xef\xef!\x8f\xd2rI\x9a\xab\xd9\xacQ\xffW\xf8py\xdf\x9a\xd6\xd5/\x0c\x8eq\xf2\x8d<\x8c\xb0g\xce\x1b\xf1\x88'
        b'\xfb\x0c\xb5B\xb7\xdd\xbe\xb3\xa9%\x05\x80\xd8\xf50\xa4\x16A\xd4w\xf9\xc6\xa5\x197\xd7\xccq\xf7N\xb8!\xe2t\x91O\xd6\x06\x05\xc9z\x1am-M\xe7\xfc\xa8\xb3\x04\x8d\xa0\xd9\xd2v5\xd3\xc2AxiY{\xd9'
        b'd\xaf\xe4h)*,\xefF\x14Dv\xa4\x14\xad\xc8ffK\xe5\xb6\xb14\xcf!\xce\xe1\xc64\x93N\xd7\n\xa8SG\xbbir\xa3\x16^\t>\xaf\xe5\xe1\xac\xa4\xf4\xc2~?\xae\xf0aB3\x97\x83m?\xe18'
        b'\xec|\xb6\xd6Nd)\x8d\xc4\xd8\x17/zJ\x8aH&\xc5k1\xfd\x96\xd33g\x0bA\x0b\x0bF\x02P5wP\xb9G\x02\xb4\xad\xc5\x04\xd8!\xa1\xaf\x81P\xc1\xf6\xc2q\x1c\xe4 \xdc\x8eV\x8e\x99zEr\t'
        b'h\xb4\x05\xacn\xf0\xf4\x86\x14\x17\xe4\xbe\xa6\xc6Za\xaeKCW\x90\x03\x82|\x15\xe2_{\xd8\xc5Jv\x0f\xba0\x1d\x80\xd6\x0ew\xea\xf4\xf6D\xcb\n\x8cS\xb4\xfe]\x13+O\x8a\xd5\t\xa0\xe1?\x08+\xa0\xd0'
        b'\xd4\x98+Y\x110&H\xc7\xec\x11\xdcO\x07A\xa9\x8b\x17N\xfa\xe3\xb6b:\x08\xd8!U"C\xd2\xe1X\x8d\xab:\xe8G\x81\x9a\xb3\xeeQ@\x0f\xee\x1dn<\tt\xd2,\'\xee`\xe7\xd5u\xe2\xe8\x847\x8b'
        b'\xa0`@Gk\xc8\x0f\x1d\x1b\x12\xcc\xc6\x89\xbd\x05\x07=X=\xa9x\xc7f\xe7\xe5u\x0f\xc4D\x06\xe1\xedv\x02\xa0\xcc\xd3\x0c\xec,\r\x88\xa9\x91u\x7f \x0ejzm\xc6\xf40\xa4\xe01m.\xf9=\xd2n\xec'
        b'\xbb\xf7\xc8\xc8G\x16\xa0;\x06S]\x9es3-~n\xf2\x91c\x13jw_k\xbf\x84_\xb3\xad\xd96#i\x87\xc1Yc\x04\xd92\x8cf\x95\x14aS\xd1\x1c\xa3\x07\xaa;M\x7f\xe8\x1f\xd5\xe4\x81\xd6\xfe\x87C'
        b'X$\x87,\x97\xbfE?\xedi~\xd2\x01k*\xcb\xe8n\x19M\x83\x7fi\xf8\xdc\xae\xf1\x19*\x84f\xa1\xd0\xd3&\xcf\x7f\xc6|\xccs\xed\xaa\xcb\xd3\xfd\x10\xdc\xae-\xd05\xdfG\xcf\xe2C\xd8\x85N8\x94\xe6\x8b'
        b'\xde\xea}j#Hq\'\x0e\x83\xe8j\x1e_\xd0W\xf8ch\x01n\xf1z\xf0GGP\xf3\xd50ftcD?xR\xf2\xda\xfa$R\xd8\xff\xcae\xa9\xcaR"|\xd2q*\xc6\xe4\x98\xedf\xf8={\xf9\x9c'
        b'\xf5\x8f\xd8~}^k\xb6C\xdbYQ\xae\xed\x1f\x16\x12\xe3\xc2\xc5\x93\x1e\xff\xae\xb6\xb3Z)N)\x04\xda\x07runtimer\x03\x00\x00\x00\xda\x08__name__\xda\x08__file_'
        b'_\xa9\x00\xf3\x00\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>r\n\x00\x00\x00\x01\x00\x00\x00s\x1d\x00\x00\x00\xf0\x03\x01\x01\x01\xe5\x00 '
        b'\xd9\x00\x0b\x88H\x90h\xf0\x00\x00!|]\r\xf5\x00\x00\x01}]\rr\x08\x00\x00\x00'
    ))
